iso6392 = {
    "roh": {
        "terminologic": "", 
        "alpha2": "rm", 
        "french": "romanche", 
        "bibliographic": "roh", 
        "english": "Romansh"
    }, 
    "gv": {
        "terminologic": "", 
        "alpha2": "gv", 
        "french": "manx; mannois", 
        "bibliographic": "glv", 
        "english": "Manx"
    }, 
    "gu": {
        "terminologic": "", 
        "alpha2": "gu", 
        "french": "goudjrati", 
        "bibliographic": "guj", 
        "english": "Gujarati"
    }, 
    "scn": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "sicilien", 
        "bibliographic": "scn", 
        "english": "Sicilian"
    }, 
    "rom": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "tsigane", 
        "bibliographic": "rom", 
        "english": "Romany"
    }, 
    "ron": {
        "terminologic": "ron", 
        "alpha2": "ro", 
        "french": "roumain; moldave", 
        "bibliographic": "rum", 
        "english": "Romanian; Moldavian; Moldovan"
    }, 
    "alg": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "algonquines, langues", 
        "bibliographic": "alg", 
        "english": "Algonquian languages"
    }, 
    "oss": {
        "terminologic": "", 
        "alpha2": "os", 
        "french": "oss\u00e8te", 
        "bibliographic": "oss", 
        "english": "Ossetian; Ossetic"
    }, 
    "ale": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "al\u00e9oute", 
        "bibliographic": "ale", 
        "english": "Aleut"
    }, 
    "alb": {
        "terminologic": "sqi", 
        "alpha2": "sq", 
        "french": "albanais", 
        "bibliographic": "alb", 
        "english": "Albanian"
    }, 
    "sco": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "\u00e9cossais", 
        "bibliographic": "sco", 
        "english": "Scots"
    }, 
    "mni": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "manipuri", 
        "bibliographic": "mni", 
        "english": "Manipuri"
    }, 
    "gd": {
        "terminologic": "", 
        "alpha2": "gd", 
        "french": "ga\u00e9lique; ga\u00e9lique \u00e9cossais", 
        "bibliographic": "gla", 
        "english": "Gaelic; Scottish Gaelic"
    }, 
    "per": {
        "terminologic": "fas", 
        "alpha2": "fa", 
        "french": "persan", 
        "bibliographic": "per", 
        "english": "Persian"
    }, 
    "ga": {
        "terminologic": "", 
        "alpha2": "ga", 
        "french": "irlandais", 
        "bibliographic": "gle", 
        "english": "Irish"
    }, 
    "mno": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "manobo, langues", 
        "bibliographic": "mno", 
        "english": "Manobo languages"
    }, 
    "osa": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "osage", 
        "bibliographic": "osa", 
        "english": "Osage"
    }, 
    "gn": {
        "terminologic": "", 
        "alpha2": "gn", 
        "french": "guarani", 
        "bibliographic": "grn", 
        "english": "Guarani"
    }, 
    "alt": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "altai du Sud", 
        "bibliographic": "alt", 
        "english": "Southern Altai"
    }, 
    "gl": {
        "terminologic": "", 
        "alpha2": "gl", 
        "french": "galicien", 
        "bibliographic": "glg", 
        "english": "Galician"
    }, 
    "mwr": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "marvari", 
        "bibliographic": "mwr", 
        "english": "Marwari"
    }, 
    "smn": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "sami d'Inari", 
        "bibliographic": "smn", 
        "english": "Inari Sami"
    }, 
    "tw": {
        "terminologic": "", 
        "alpha2": "tw", 
        "french": "twi", 
        "bibliographic": "twi", 
        "english": "Twi"
    }, 
    "tt": {
        "terminologic": "", 
        "alpha2": "tt", 
        "french": "tatar", 
        "bibliographic": "tat", 
        "english": "Tatar"
    }, 
    "tr": {
        "terminologic": "", 
        "alpha2": "tr", 
        "french": "turc", 
        "bibliographic": "tur", 
        "english": "Turkish"
    }, 
    "ts": {
        "terminologic": "", 
        "alpha2": "ts", 
        "french": "tsonga", 
        "bibliographic": "tso", 
        "english": "Tsonga"
    }, 
    "tn": {
        "terminologic": "", 
        "alpha2": "tn", 
        "french": "tswana", 
        "bibliographic": "tsn", 
        "english": "Tswana"
    }, 
    "to": {
        "terminologic": "", 
        "alpha2": "to", 
        "french": "tongan (\u00celes Tonga)", 
        "bibliographic": "ton", 
        "english": "Tonga (Tonga Islands)"
    }, 
    "aus": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "australiennes, langues", 
        "bibliographic": "aus", 
        "english": "Australian languages"
    }, 
    "tk": {
        "terminologic": "", 
        "alpha2": "tk", 
        "french": "turkm\u00e8ne", 
        "bibliographic": "tuk", 
        "english": "Turkmen"
    }, 
    "th": {
        "terminologic": "", 
        "alpha2": "th", 
        "french": "tha\u00ef", 
        "bibliographic": "tha", 
        "english": "Thai"
    }, 
    "roa": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "romanes, langues", 
        "bibliographic": "roa", 
        "english": "Romance languages"
    }, 
    "ven": {
        "terminologic": "", 
        "alpha2": "ve", 
        "french": "venda", 
        "bibliographic": "ven", 
        "english": "Venda"
    }, 
    "tg": {
        "terminologic": "", 
        "alpha2": "tg", 
        "french": "tadjik", 
        "bibliographic": "tgk", 
        "english": "Tajik"
    }, 
    "te": {
        "terminologic": "", 
        "alpha2": "te", 
        "french": "t\u00e9lougou", 
        "bibliographic": "tel", 
        "english": "Telugu"
    }, 
    "uga": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "ougaritique", 
        "bibliographic": "uga", 
        "english": "Ugaritic"
    }, 
    "mwl": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "mirandais", 
        "bibliographic": "mwl", 
        "english": "Mirandese"
    }, 
    "ty": {
        "terminologic": "", 
        "alpha2": "ty", 
        "french": "tahitien", 
        "bibliographic": "tah", 
        "english": "Tahitian"
    }, 
    "fas": {
        "terminologic": "fas", 
        "alpha2": "fa", 
        "french": "persan", 
        "bibliographic": "per", 
        "english": "Persian"
    }, 
    "fat": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "fanti", 
        "bibliographic": "fat", 
        "english": "Fanti"
    }, 
    "qaa-qtz": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "r\u00e9serv\u00e9e \u00e0 l'usage local", 
        "bibliographic": "qaa-qtz", 
        "english": "Reserved for local use"
    }, 
    "ay": {
        "terminologic": "", 
        "alpha2": "ay", 
        "french": "aymara", 
        "bibliographic": "aym", 
        "english": "Aymara"
    }, 
    "fan": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "fang", 
        "bibliographic": "fan", 
        "english": "Fang"
    }, 
    "fao": {
        "terminologic": "", 
        "alpha2": "fo", 
        "french": "f\u00e9ro\u00efen", 
        "bibliographic": "fao", 
        "english": "Faroese"
    }, 
    "wo": {
        "terminologic": "", 
        "alpha2": "wo", 
        "french": "wolof", 
        "bibliographic": "wol", 
        "english": "Wolof"
    }, 
    "rm": {
        "terminologic": "", 
        "alpha2": "rm", 
        "french": "romanche", 
        "bibliographic": "roh", 
        "english": "Romansh"
    }, 
    "sme": {
        "terminologic": "", 
        "alpha2": "se", 
        "french": "sami du Nord", 
        "bibliographic": "sme", 
        "english": "Northern Sami"
    }, 
    "din": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "dinka", 
        "bibliographic": "din", 
        "english": "Dinka"
    }, 
    "hye": {
        "terminologic": "hye", 
        "alpha2": "hy", 
        "french": "arm\u00e9nien", 
        "bibliographic": "arm", 
        "english": "Armenian"
    }, 
    "guj": {
        "terminologic": "", 
        "alpha2": "gu", 
        "french": "goudjrati", 
        "bibliographic": "guj", 
        "english": "Gujarati"
    }, 
    "cmc": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "chames, langues", 
        "bibliographic": "cmc", 
        "english": "Chamic languages"
    }, 
    "srd": {
        "terminologic": "", 
        "alpha2": "sc", 
        "french": "sarde", 
        "bibliographic": "srd", 
        "english": "Sardinian"
    }, 
    "mdr": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "mandar", 
        "bibliographic": "mdr", 
        "english": "Mandar"
    }, 
    "car": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "karib; galibi; carib", 
        "bibliographic": "car", 
        "english": "Galibi Carib"
    }, 
    "div": {
        "terminologic": "", 
        "alpha2": "dv", 
        "french": "maldivien", 
        "bibliographic": "div", 
        "english": "Divehi; Dhivehi; Maldivian"
    }, 
    "zh": {
        "terminologic": "zho", 
        "alpha2": "zh", 
        "french": "chinois", 
        "bibliographic": "chi", 
        "english": "Chinese"
    }, 
    "tem": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "temne", 
        "bibliographic": "tem", 
        "english": "Timne"
    }, 
    "xho": {
        "terminologic": "", 
        "alpha2": "xh", 
        "french": "xhosa", 
        "bibliographic": "xho", 
        "english": "Xhosa"
    }, 
    "nwc": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "newari classique", 
        "bibliographic": "nwc", 
        "english": "Classical Newari; Old Newari; Classical Nepal Bhasa"
    }, 
    "za": {
        "terminologic": "", 
        "alpha2": "za", 
        "french": "zhuang; chuang", 
        "bibliographic": "zha", 
        "english": "Zhuang; Chuang"
    }, 
    "mh": {
        "terminologic": "", 
        "alpha2": "mh", 
        "french": "marshall", 
        "bibliographic": "mah", 
        "english": "Marshallese"
    }, 
    "mk": {
        "terminologic": "mkd", 
        "alpha2": "mk", 
        "french": "mac\u00e9donien", 
        "bibliographic": "mac", 
        "english": "Macedonian"
    }, 
    "nbl": {
        "terminologic": "", 
        "alpha2": "nr", 
        "french": "nd\u00e9b\u00e9l\u00e9 du Sud", 
        "bibliographic": "nbl", 
        "english": "Ndebele, South; South Ndebele"
    }, 
    "zu": {
        "terminologic": "", 
        "alpha2": "zu", 
        "french": "zoulou", 
        "bibliographic": "zul", 
        "english": "Zulu"
    }, 
    "ter": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "tereno", 
        "bibliographic": "ter", 
        "english": "Tereno"
    }, 
    "tet": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "tetum", 
        "bibliographic": "tet", 
        "english": "Tetum"
    }, 
    "mnc": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "mandchou", 
        "bibliographic": "mnc", 
        "english": "Manchu"
    }, 
    "sun": {
        "terminologic": "", 
        "alpha2": "su", 
        "french": "soundanais", 
        "bibliographic": "sun", 
        "english": "Sundanese"
    }, 
    "abk": {
        "terminologic": "", 
        "alpha2": "ab", 
        "french": "abkhaze", 
        "bibliographic": "abk", 
        "english": "Abkhazian"
    }, 
    "suk": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "sukuma", 
        "bibliographic": "suk", 
        "english": "Sukuma"
    }, 
    "kur": {
        "terminologic": "", 
        "alpha2": "ku", 
        "french": "kurde", 
        "bibliographic": "kur", 
        "english": "Kurdish"
    }, 
    "kum": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "koumyk", 
        "bibliographic": "kum", 
        "english": "Kumyk"
    }, 
    "slo": {
        "terminologic": "slk", 
        "alpha2": "sk", 
        "french": "slovaque", 
        "bibliographic": "slo", 
        "english": "Slovak"
    }, 
    "sus": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "soussou", 
        "bibliographic": "sus", 
        "english": "Susu"
    }, 
    "new": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "nepal bhasa; newari", 
        "bibliographic": "new", 
        "english": "Nepal Bhasa; Newari"
    }, 
    "kua": {
        "terminologic": "", 
        "alpha2": "kj", 
        "french": "kuanyama; kwanyama", 
        "bibliographic": "kua", 
        "english": "Kuanyama; Kwanyama"
    }, 
    "sux": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "sum\u00e9rien", 
        "bibliographic": "sux", 
        "english": "Sumerian"
    }, 
    "ms": {
        "terminologic": "msa", 
        "alpha2": "ms", 
        "french": "malais", 
        "bibliographic": "may", 
        "english": "Malay"
    }, 
    "men": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "mend\u00e9", 
        "bibliographic": "men", 
        "english": "Mende"
    }, 
    "mul": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "multilingue", 
        "bibliographic": "mul", 
        "english": "Multiple languages"
    }, 
    "lez": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "lezghien", 
        "bibliographic": "lez", 
        "english": "Lezghian"
    }, 
    "gla": {
        "terminologic": "", 
        "alpha2": "gd", 
        "french": "ga\u00e9lique; ga\u00e9lique \u00e9cossais", 
        "bibliographic": "gla", 
        "english": "Gaelic; Scottish Gaelic"
    }, 
    "bos": {
        "terminologic": "", 
        "alpha2": "bs", 
        "french": "bosniaque", 
        "bibliographic": "bos", 
        "english": "Bosnian"
    }, 
    "gle": {
        "terminologic": "", 
        "alpha2": "ga", 
        "french": "irlandais", 
        "bibliographic": "gle", 
        "english": "Irish"
    }, 
    "eka": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "ekajuk", 
        "bibliographic": "eka", 
        "english": "Ekajuk"
    }, 
    "glg": {
        "terminologic": "", 
        "alpha2": "gl", 
        "french": "galicien", 
        "bibliographic": "glg", 
        "english": "Galician"
    }, 
    "akk": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "akkadien", 
        "bibliographic": "akk", 
        "english": "Akkadian"
    }, 
    "uzb": {
        "terminologic": "", 
        "alpha2": "uz", 
        "french": "ouszbek", 
        "bibliographic": "uzb", 
        "english": "Uzbek"
    }, 
    "dra": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "dravidiennes, langues", 
        "bibliographic": "dra", 
        "english": "Dravidian languages"
    }, 
    "aka": {
        "terminologic": "", 
        "alpha2": "ak", 
        "french": "akan", 
        "bibliographic": "aka", 
        "english": "Akan"
    }, 
    "bod": {
        "terminologic": "bod", 
        "alpha2": "bo", 
        "french": "tib\u00e9tain", 
        "bibliographic": "tib", 
        "english": "Tibetan"
    }, 
    "glv": {
        "terminologic": "", 
        "alpha2": "gv", 
        "french": "manx; mannois", 
        "bibliographic": "glv", 
        "english": "Manx"
    }, 
    "jrb": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "jud\u00e9o-arabe", 
        "bibliographic": "jrb", 
        "english": "Judeo-Arabic"
    }, 
    "vie": {
        "terminologic": "", 
        "alpha2": "vi", 
        "french": "vietnamien", 
        "bibliographic": "vie", 
        "english": "Vietnamese"
    }, 
    "ipk": {
        "terminologic": "", 
        "alpha2": "ik", 
        "french": "inupiaq", 
        "bibliographic": "ipk", 
        "english": "Inupiaq"
    }, 
    "rum": {
        "terminologic": "ron", 
        "alpha2": "ro", 
        "french": "roumain; moldave", 
        "bibliographic": "rum", 
        "english": "Romanian; Moldavian; Moldovan"
    }, 
    "sgn": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "langues des signes", 
        "bibliographic": "sgn", 
        "english": "Sign Languages"
    }, 
    "sga": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "irlandais ancien (jusqu'\u00e0 900)", 
        "bibliographic": "sga", 
        "english": "Irish, Old (to 900)"
    }, 
    "afa": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "afro-asiatiques, langues", 
        "bibliographic": "afa", 
        "english": "Afro-Asiatic languages"
    }, 
    "bre": {
        "terminologic": "", 
        "alpha2": "br", 
        "french": "breton", 
        "bibliographic": "bre", 
        "english": "Breton"
    }, 
    "apa": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "apaches, langues", 
        "bibliographic": "apa", 
        "english": "Apache languages"
    }, 
    "bra": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "braj", 
        "bibliographic": "bra", 
        "english": "Braj"
    }, 
    "aym": {
        "terminologic": "", 
        "alpha2": "ay", 
        "french": "aymara", 
        "bibliographic": "aym", 
        "english": "Aymara"
    }, 
    "cha": {
        "terminologic": "", 
        "alpha2": "ch", 
        "french": "chamorro", 
        "bibliographic": "cha", 
        "english": "Chamorro"
    }, 
    "chb": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "chibcha", 
        "bibliographic": "chb", 
        "english": "Chibcha"
    }, 
    "che": {
        "terminologic": "", 
        "alpha2": "ce", 
        "french": "tch\u00e9tch\u00e8ne", 
        "bibliographic": "che", 
        "english": "Chechen"
    }, 
    "chg": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "djaghata\u00ef", 
        "bibliographic": "chg", 
        "english": "Chagatai"
    }, 
    "chi": {
        "terminologic": "zho", 
        "alpha2": "zh", 
        "french": "chinois", 
        "bibliographic": "chi", 
        "english": "Chinese"
    }, 
    "chk": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "chuuk", 
        "bibliographic": "chk", 
        "english": "Chuukese"
    }, 
    "chm": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "mari", 
        "bibliographic": "chm", 
        "english": "Mari"
    }, 
    "chn": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "chinook, jargon", 
        "bibliographic": "chn", 
        "english": "Chinook jargon"
    }, 
    "cho": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "choctaw", 
        "bibliographic": "cho", 
        "english": "Choctaw"
    }, 
    "chp": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "chipewyan", 
        "bibliographic": "chp", 
        "english": "Chipewyan; Dene Suline"
    }, 
    "chr": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "cherokee", 
        "bibliographic": "chr", 
        "english": "Cherokee"
    }, 
    "chu": {
        "terminologic": "", 
        "alpha2": "cu", 
        "french": "slavon d'\u00e9glise; vieux slave; slavon liturgique; vieux bulgare", 
        "bibliographic": "chu", 
        "english": "Church Slavic; Old Slavonic; Church Slavonic; Old Bulgarian; Old Church Slavonic"
    }, 
    "chv": {
        "terminologic": "", 
        "alpha2": "cv", 
        "french": "tchouvache", 
        "bibliographic": "chv", 
        "english": "Chuvash"
    }, 
    "chy": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "cheyenne", 
        "bibliographic": "chy", 
        "english": "Cheyenne"
    }, 
    "msa": {
        "terminologic": "msa", 
        "alpha2": "ms", 
        "french": "malais", 
        "bibliographic": "may", 
        "english": "Malay"
    }, 
    "ti": {
        "terminologic": "", 
        "alpha2": "ti", 
        "french": "tigrigna", 
        "bibliographic": "tir", 
        "english": "Tigrinya"
    }, 
    "iii": {
        "terminologic": "", 
        "alpha2": "ii", 
        "french": "yi de Sichuan", 
        "bibliographic": "iii", 
        "english": "Sichuan Yi; Nuosu"
    }, 
    "ml": {
        "terminologic": "", 
        "alpha2": "ml", 
        "french": "malayalam", 
        "bibliographic": "mal", 
        "english": "Malayalam"
    }, 
    "vot": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "vote", 
        "bibliographic": "vot", 
        "english": "Votic"
    }, 
    "mg": {
        "terminologic": "", 
        "alpha2": "mg", 
        "french": "malgache", 
        "bibliographic": "mlg", 
        "english": "Malagasy"
    }, 
    "ndo": {
        "terminologic": "", 
        "alpha2": "ng", 
        "french": "ndonga", 
        "bibliographic": "ndo", 
        "english": "Ndonga"
    }, 
    "ibo": {
        "terminologic": "", 
        "alpha2": "ig", 
        "french": "igbo", 
        "bibliographic": "ibo", 
        "english": "Igbo"
    }, 
    "iba": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "iban", 
        "bibliographic": "iba", 
        "english": "Iban"
    }, 
    "mn": {
        "terminologic": "", 
        "alpha2": "mn", 
        "french": "mongol", 
        "bibliographic": "mon", 
        "english": "Mongolian"
    }, 
    "mi": {
        "terminologic": "mri", 
        "alpha2": "mi", 
        "french": "maori", 
        "bibliographic": "mao", 
        "english": "Maori"
    }, 
    "deu": {
        "terminologic": "deu", 
        "alpha2": "de", 
        "french": "allemand", 
        "bibliographic": "ger", 
        "english": "German"
    }, 
    "cau": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "caucasiennes, langues", 
        "bibliographic": "cau", 
        "english": "Caucasian languages"
    }, 
    "cat": {
        "terminologic": "", 
        "alpha2": "ca", 
        "french": "catalan; valencien", 
        "bibliographic": "cat", 
        "english": "Catalan; Valencian"
    }, 
    "mt": {
        "terminologic": "", 
        "alpha2": "mt", 
        "french": "maltais", 
        "bibliographic": "mlt", 
        "english": "Maltese"
    }, 
    "cai": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "am\u00e9rindiennes de L'Am\u00e9rique centrale, langues", 
        "bibliographic": "cai", 
        "english": "Central American Indian languages"
    }, 
    "del": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "delaware", 
        "bibliographic": "del", 
        "english": "Delaware"
    }, 
    "den": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "esclave (athapascan)", 
        "bibliographic": "den", 
        "english": "Slave (Athapascan)"
    }, 
    "mr": {
        "terminologic": "", 
        "alpha2": "mr", 
        "french": "marathe", 
        "bibliographic": "mar", 
        "english": "Marathi"
    }, 
    "ta": {
        "terminologic": "", 
        "alpha2": "ta", 
        "french": "tamoul", 
        "bibliographic": "tam", 
        "english": "Tamil"
    }, 
    "my": {
        "terminologic": "mya", 
        "alpha2": "my", 
        "french": "birman", 
        "bibliographic": "bur", 
        "english": "Burmese"
    }, 
    "cad": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "caddo", 
        "bibliographic": "cad", 
        "english": "Caddo"
    }, 
    "tat": {
        "terminologic": "", 
        "alpha2": "tt", 
        "french": "tatar", 
        "bibliographic": "tat", 
        "english": "Tatar"
    }, 
    "oc": {
        "terminologic": "", 
        "alpha2": "oc", 
        "french": "occitan (apr\u00e8s 1500); proven\u00e7al", 
        "bibliographic": "oci", 
        "english": "Occitan (post 1500); Proven\u00e7al"
    }, 
    "tam": {
        "terminologic": "", 
        "alpha2": "ta", 
        "french": "tamoul", 
        "bibliographic": "tam", 
        "english": "Tamil"
    }, 
    "spa": {
        "terminologic": "", 
        "alpha2": "es", 
        "french": "espagnol; castillan", 
        "bibliographic": "spa", 
        "english": "Spanish; Castilian"
    }, 
    "tah": {
        "terminologic": "", 
        "alpha2": "ty", 
        "french": "tahitien", 
        "bibliographic": "tah", 
        "english": "Tahitian"
    }, 
    "tai": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "tai, langues", 
        "bibliographic": "tai", 
        "english": "Tai languages"
    }, 
    "cze": {
        "terminologic": "ces", 
        "alpha2": "cs", 
        "french": "tch\u00e8que", 
        "bibliographic": "cze", 
        "english": "Czech"
    }, 
    "afh": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "afrihili", 
        "bibliographic": "afh", 
        "english": "Afrihili"
    }, 
    "eng": {
        "terminologic": "", 
        "alpha2": "en", 
        "french": "anglais", 
        "bibliographic": "eng", 
        "english": "English"
    }, 
    "enm": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "anglais moyen (1100-1500)", 
        "bibliographic": "enm", 
        "english": "English, Middle (1100-1500)"
    }, 
    "ava": {
        "terminologic": "", 
        "alpha2": "av", 
        "french": "avar", 
        "bibliographic": "ava", 
        "english": "Avaric"
    }, 
    "nyn": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "nyankol\u00e9", 
        "bibliographic": "nyn", 
        "english": "Nyankole"
    }, 
    "nyo": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "nyoro", 
        "bibliographic": "nyo", 
        "english": "Nyoro"
    }, 
    "gez": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "gu\u00e8ze", 
        "bibliographic": "gez", 
        "english": "Geez"
    }, 
    "nya": {
        "terminologic": "", 
        "alpha2": "ny", 
        "french": "chichewa; chewa; nyanja", 
        "bibliographic": "nya", 
        "english": "Chichewa; Chewa; Nyanja"
    }, 
    "sio": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "sioux, langues", 
        "bibliographic": "sio", 
        "english": "Siouan languages"
    }, 
    "sin": {
        "terminologic": "", 
        "alpha2": "si", 
        "french": "singhalais", 
        "bibliographic": "sin", 
        "english": "Sinhala; Sinhalese"
    }, 
    "afr": {
        "terminologic": "", 
        "alpha2": "af", 
        "french": "afrikaans", 
        "bibliographic": "afr", 
        "english": "Afrikaans"
    }, 
    "lam": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "lamba", 
        "bibliographic": "lam", 
        "english": "Lamba"
    }, 
    "fr": {
        "terminologic": "fra", 
        "alpha2": "fr", 
        "french": "fran\u00e7ais", 
        "bibliographic": "fre", 
        "english": "French"
    }, 
    "lao": {
        "terminologic": "", 
        "alpha2": "lo", 
        "french": "lao", 
        "bibliographic": "lao", 
        "english": "Lao"
    }, 
    "lah": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "lahnda", 
        "bibliographic": "lah", 
        "english": "Lahnda"
    }, 
    "nym": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "nyamwezi", 
        "bibliographic": "nym", 
        "english": "Nyamwezi"
    }, 
    "sna": {
        "terminologic": "", 
        "alpha2": "sn", 
        "french": "shona", 
        "bibliographic": "sna", 
        "english": "Shona"
    }, 
    "lad": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "jud\u00e9o-espagnol", 
        "bibliographic": "lad", 
        "english": "Ladino"
    }, 
    "fy": {
        "terminologic": "", 
        "alpha2": "fy", 
        "french": "frison occidental", 
        "bibliographic": "fry", 
        "english": "Western Frisian"
    }, 
    "snk": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "sonink\u00e9", 
        "bibliographic": "snk", 
        "english": "Soninke"
    }, 
    "fa": {
        "terminologic": "fas", 
        "alpha2": "fa", 
        "french": "persan", 
        "bibliographic": "per", 
        "english": "Persian"
    }, 
    "mac": {
        "terminologic": "mkd", 
        "alpha2": "mk", 
        "french": "mac\u00e9donien", 
        "bibliographic": "mac", 
        "english": "Macedonian"
    }, 
    "mad": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "madourais", 
        "bibliographic": "mad", 
        "english": "Madurese"
    }, 
    "ff": {
        "terminologic": "", 
        "alpha2": "ff", 
        "french": "peul", 
        "bibliographic": "ful", 
        "english": "Fulah"
    }, 
    "lat": {
        "terminologic": "", 
        "alpha2": "la", 
        "french": "latin", 
        "bibliographic": "lat", 
        "english": "Latin"
    }, 
    "fi": {
        "terminologic": "", 
        "alpha2": "fi", 
        "french": "finnois", 
        "bibliographic": "fin", 
        "english": "Finnish"
    }, 
    "fj": {
        "terminologic": "", 
        "alpha2": "fj", 
        "french": "fidjien", 
        "bibliographic": "fij", 
        "english": "Fijian"
    }, 
    "mal": {
        "terminologic": "", 
        "alpha2": "ml", 
        "french": "malayalam", 
        "bibliographic": "mal", 
        "english": "Malayalam"
    }, 
    "mao": {
        "terminologic": "mri", 
        "alpha2": "mi", 
        "french": "maori", 
        "bibliographic": "mao", 
        "english": "Maori"
    }, 
    "fo": {
        "terminologic": "", 
        "alpha2": "fo", 
        "french": "f\u00e9ro\u00efen", 
        "bibliographic": "fao", 
        "english": "Faroese"
    }, 
    "mak": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "makassar", 
        "bibliographic": "mak", 
        "english": "Makasar"
    }, 
    "egy": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "\u00e9gyptien", 
        "bibliographic": "egy", 
        "english": "Egyptian (Ancient)"
    }, 
    "znd": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "zand\u00e9, langues", 
        "bibliographic": "znd", 
        "english": "Zande languages"
    }, 
    "ss": {
        "terminologic": "", 
        "alpha2": "ss", 
        "french": "swati", 
        "bibliographic": "ssw", 
        "english": "Swati"
    }, 
    "sr": {
        "terminologic": "", 
        "alpha2": "sr", 
        "french": "serbe", 
        "bibliographic": "srp", 
        "english": "Serbian"
    }, 
    "sq": {
        "terminologic": "sqi", 
        "alpha2": "sq", 
        "french": "albanais", 
        "bibliographic": "alb", 
        "english": "Albanian"
    }, 
    "sit": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "sino-tib\u00e9taines, langues", 
        "bibliographic": "sit", 
        "english": "Sino-Tibetan languages"
    }, 
    "sw": {
        "terminologic": "", 
        "alpha2": "sw", 
        "french": "swahili", 
        "bibliographic": "swa", 
        "english": "Swahili"
    }, 
    "sv": {
        "terminologic": "", 
        "alpha2": "sv", 
        "french": "su\u00e9dois", 
        "bibliographic": "swe", 
        "english": "Swedish"
    }, 
    "su": {
        "terminologic": "", 
        "alpha2": "su", 
        "french": "soundanais", 
        "bibliographic": "sun", 
        "english": "Sundanese"
    }, 
    "st": {
        "terminologic": "", 
        "alpha2": "st", 
        "french": "sotho du Sud", 
        "bibliographic": "sot", 
        "english": "Sotho, Southern"
    }, 
    "sk": {
        "terminologic": "slk", 
        "alpha2": "sk", 
        "french": "slovaque", 
        "bibliographic": "slo", 
        "english": "Slovak"
    }, 
    "si": {
        "terminologic": "", 
        "alpha2": "si", 
        "french": "singhalais", 
        "bibliographic": "sin", 
        "english": "Sinhala; Sinhalese"
    }, 
    "so": {
        "terminologic": "", 
        "alpha2": "so", 
        "french": "somali", 
        "bibliographic": "som", 
        "english": "Somali"
    }, 
    "sn": {
        "terminologic": "", 
        "alpha2": "sn", 
        "french": "shona", 
        "bibliographic": "sna", 
        "english": "Shona"
    }, 
    "sm": {
        "terminologic": "", 
        "alpha2": "sm", 
        "french": "samoan", 
        "bibliographic": "smo", 
        "english": "Samoan"
    }, 
    "sl": {
        "terminologic": "", 
        "alpha2": "sl", 
        "french": "slov\u00e8ne", 
        "bibliographic": "slv", 
        "english": "Slovenian"
    }, 
    "sc": {
        "terminologic": "", 
        "alpha2": "sc", 
        "french": "sarde", 
        "bibliographic": "srd", 
        "english": "Sardinian"
    }, 
    "sa": {
        "terminologic": "", 
        "alpha2": "sa", 
        "french": "sanskrit", 
        "bibliographic": "san", 
        "english": "Sanskrit"
    }, 
    "sg": {
        "terminologic": "", 
        "alpha2": "sg", 
        "french": "sango", 
        "bibliographic": "sag", 
        "english": "Sango"
    }, 
    "se": {
        "terminologic": "", 
        "alpha2": "se", 
        "french": "sami du Nord", 
        "bibliographic": "sme", 
        "english": "Northern Sami"
    }, 
    "sd": {
        "terminologic": "", 
        "alpha2": "sd", 
        "french": "sindhi", 
        "bibliographic": "snd", 
        "english": "Sindhi"
    }, 
    "zen": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "zenaga", 
        "bibliographic": "zen", 
        "english": "Zenaga"
    }, 
    "kbd": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "kabardien", 
        "bibliographic": "kbd", 
        "english": "Kabardian"
    }, 
    "ita": {
        "terminologic": "", 
        "alpha2": "it", 
        "french": "italien", 
        "bibliographic": "ita", 
        "english": "Italian"
    }, 
    "vai": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "va\u00ef", 
        "bibliographic": "vai", 
        "english": "Vai"
    }, 
    "csb": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "kachoube", 
        "bibliographic": "csb", 
        "english": "Kashubian"
    }, 
    "tsn": {
        "terminologic": "", 
        "alpha2": "tn", 
        "french": "tswana", 
        "bibliographic": "tsn", 
        "english": "Tswana"
    }, 
    "lg": {
        "terminologic": "", 
        "alpha2": "lg", 
        "french": "ganda", 
        "bibliographic": "lug", 
        "english": "Ganda"
    }, 
    "pt": {
        "terminologic": "", 
        "alpha2": "pt", 
        "french": "portugais", 
        "bibliographic": "por", 
        "english": "Portuguese"
    }, 
    "lb": {
        "terminologic": "", 
        "alpha2": "lb", 
        "french": "luxembourgeois", 
        "bibliographic": "ltz", 
        "english": "Luxembourgish; Letzeburgesch"
    }, 
    "fiu": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "finno-ougriennes, langues", 
        "bibliographic": "fiu", 
        "english": "Finno-Ugrian languages"
    }, 
    "ln": {
        "terminologic": "", 
        "alpha2": "ln", 
        "french": "lingala", 
        "bibliographic": "lin", 
        "english": "Lingala"
    }, 
    "geo": {
        "terminologic": "kat", 
        "alpha2": "ka", 
        "french": "g\u00e9orgien", 
        "bibliographic": "geo", 
        "english": "Georgian"
    }, 
    "li": {
        "terminologic": "", 
        "alpha2": "li", 
        "french": "limbourgeois", 
        "bibliographic": "lim", 
        "english": "Limburgan; Limburger; Limburgish"
    }, 
    "byn": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "blin; bilen", 
        "bibliographic": "byn", 
        "english": "Blin; Bilin"
    }, 
    "lt": {
        "terminologic": "", 
        "alpha2": "lt", 
        "french": "lituanien", 
        "bibliographic": "lit", 
        "english": "Lithuanian"
    }, 
    "lu": {
        "terminologic": "", 
        "alpha2": "lu", 
        "french": "luba-katanga", 
        "bibliographic": "lub", 
        "english": "Luba-Katanga"
    }, 
    "gem": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "germaniques, langues", 
        "bibliographic": "gem", 
        "english": "Germanic languages"
    }, 
    "fij": {
        "terminologic": "", 
        "alpha2": "fj", 
        "french": "fidjien", 
        "bibliographic": "fij", 
        "english": "Fijian"
    }, 
    "fin": {
        "terminologic": "", 
        "alpha2": "fi", 
        "french": "finnois", 
        "bibliographic": "fin", 
        "english": "Finnish"
    }, 
    "eus": {
        "terminologic": "eus", 
        "alpha2": "eu", 
        "french": "basque", 
        "bibliographic": "baq", 
        "english": "Basque"
    }, 
    "yi": {
        "terminologic": "", 
        "alpha2": "yi", 
        "french": "yiddish", 
        "bibliographic": "yid", 
        "english": "Yiddish"
    }, 
    "non": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "norrois, vieux", 
        "bibliographic": "non", 
        "english": "Norse, Old"
    }, 
    "ceb": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "cebuano", 
        "bibliographic": "ceb", 
        "english": "Cebuano"
    }, 
    "yo": {
        "terminologic": "", 
        "alpha2": "yo", 
        "french": "yoruba", 
        "bibliographic": "yor", 
        "english": "Yoruba"
    }, 
    "dan": {
        "terminologic": "", 
        "alpha2": "da", 
        "french": "danois", 
        "bibliographic": "dan", 
        "english": "Danish"
    }, 
    "cel": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "celtiques, langues; celtes, langues", 
        "bibliographic": "cel", 
        "english": "Celtic languages"
    }, 
    "bat": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "baltes, langues", 
        "bibliographic": "bat", 
        "english": "Baltic languages"
    }, 
    "nob": {
        "terminologic": "", 
        "alpha2": "nb", 
        "french": "norv\u00e9gien bokm\u00e5l", 
        "bibliographic": "nob", 
        "english": "Bokm\u00e5l, Norwegian; Norwegian Bokm\u00e5l"
    }, 
    "dak": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "dakota", 
        "bibliographic": "dak", 
        "english": "Dakota"
    }, 
    "ces": {
        "terminologic": "ces", 
        "alpha2": "cs", 
        "french": "tch\u00e8que", 
        "bibliographic": "cze", 
        "english": "Czech"
    }, 
    "dar": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "dargwa", 
        "bibliographic": "dar", 
        "english": "Dargwa"
    }, 
    "qu": {
        "terminologic": "", 
        "alpha2": "qu", 
        "french": "quechua", 
        "bibliographic": "que", 
        "english": "Quechua"
    }, 
    "day": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "dayak, langues", 
        "bibliographic": "day", 
        "english": "Land Dayak languages"
    }, 
    "nor": {
        "terminologic": "", 
        "alpha2": "no", 
        "french": "norv\u00e9gien", 
        "bibliographic": "nor", 
        "english": "Norwegian"
    }, 
    "gba": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "gbaya", 
        "bibliographic": "gba", 
        "english": "Gbaya"
    }, 
    "ssa": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "nilo-sahariennes, langues", 
        "bibliographic": "ssa", 
        "english": "Nilo-Saharan languages"
    }, 
    "kpe": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "kpell\u00e9", 
        "bibliographic": "kpe", 
        "english": "Kpelle"
    }, 
    "man": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "mandingue", 
        "bibliographic": "man", 
        "english": "Mandingo"
    }, 
    "wel": {
        "terminologic": "cym", 
        "alpha2": "cy", 
        "french": "gallois", 
        "bibliographic": "wel", 
        "english": "Welsh"
    }, 
    "el": {
        "terminologic": "ell", 
        "alpha2": "el", 
        "french": "grec moderne (apr\u00e8s 1453)", 
        "bibliographic": "gre", 
        "english": "Greek, Modern (1453-)"
    }, 
    "eo": {
        "terminologic": "", 
        "alpha2": "eo", 
        "french": "esp\u00e9ranto", 
        "bibliographic": "epo", 
        "english": "Esperanto"
    }, 
    "en": {
        "terminologic": "", 
        "alpha2": "en", 
        "french": "anglais", 
        "bibliographic": "eng", 
        "english": "English"
    }, 
    "map": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "austron\u00e9siennes, langues", 
        "bibliographic": "map", 
        "english": "Austronesian languages"
    }, 
    "ee": {
        "terminologic": "", 
        "alpha2": "ee", 
        "french": "\u00e9w\u00e9", 
        "bibliographic": "ewe", 
        "english": "Ewe"
    }, 
    "tpi": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "tok pisin", 
        "bibliographic": "tpi", 
        "english": "Tok Pisin"
    }, 
    "mdf": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "moksa", 
        "bibliographic": "mdf", 
        "english": "Moksha"
    }, 
    "mas": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "massa\u00ef", 
        "bibliographic": "mas", 
        "english": "Masai"
    }, 
    "mar": {
        "terminologic": "", 
        "alpha2": "mr", 
        "french": "marathe", 
        "bibliographic": "mar", 
        "english": "Marathi"
    }, 
    "eu": {
        "terminologic": "eus", 
        "alpha2": "eu", 
        "french": "basque", 
        "bibliographic": "baq", 
        "english": "Basque"
    }, 
    "et": {
        "terminologic": "", 
        "alpha2": "et", 
        "french": "estonien", 
        "bibliographic": "est", 
        "english": "Estonian"
    }, 
    "es": {
        "terminologic": "", 
        "alpha2": "es", 
        "french": "espagnol; castillan", 
        "bibliographic": "spa", 
        "english": "Spanish; Castilian"
    }, 
    "ru": {
        "terminologic": "", 
        "alpha2": "ru", 
        "french": "russe", 
        "bibliographic": "rus", 
        "english": "Russian"
    }, 
    "rw": {
        "terminologic": "", 
        "alpha2": "rw", 
        "french": "rwanda", 
        "bibliographic": "kin", 
        "english": "Kinyarwanda"
    }, 
    "goh": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "allemand, vieux haut (ca. 750-1050)", 
        "bibliographic": "goh", 
        "english": "German, Old High (ca.750-1050)"
    }, 
    "sms": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "sami skolt", 
        "bibliographic": "sms", 
        "english": "Skolt Sami"
    }, 
    "tiv": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "tiv", 
        "bibliographic": "tiv", 
        "english": "Tiv"
    }, 
    "smo": {
        "terminologic": "", 
        "alpha2": "sm", 
        "french": "samoan", 
        "bibliographic": "smo", 
        "english": "Samoan"
    }, 
    "may": {
        "terminologic": "msa", 
        "alpha2": "ms", 
        "french": "malais", 
        "bibliographic": "may", 
        "english": "Malay"
    }, 
    "smj": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "sami de Lule", 
        "bibliographic": "smj", 
        "english": "Lule Sami"
    }, 
    "smi": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "sames, langues", 
        "bibliographic": "smi", 
        "english": "Sami languages"
    }, 
    "nic": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "nig\u00e9ro-kordofaniennes, langues", 
        "bibliographic": "nic", 
        "english": "Niger-Kordofanian languages"
    }, 
    "got": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "gothique", 
        "bibliographic": "got", 
        "english": "Gothic"
    }, 
    "rn": {
        "terminologic": "", 
        "alpha2": "rn", 
        "french": "rundi", 
        "bibliographic": "run", 
        "english": "Rundi"
    }, 
    "ro": {
        "terminologic": "ron", 
        "alpha2": "ro", 
        "french": "roumain; moldave", 
        "bibliographic": "rum", 
        "english": "Romanian; Moldavian; Moldovan"
    }, 
    "dsb": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "bas-sorabe", 
        "bibliographic": "dsb", 
        "english": "Lower Sorbian"
    }, 
    "sma": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "sami du Sud", 
        "bibliographic": "sma", 
        "english": "Southern Sami"
    }, 
    "gor": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "gorontalo", 
        "bibliographic": "gor", 
        "english": "Gorontalo"
    }, 
    "ast": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "asturien; bable; l\u00e9onais; asturol\u00e9onais", 
        "bibliographic": "ast", 
        "english": "Asturian; Bable; Leonese; Asturleonese"
    }, 
    "orm": {
        "terminologic": "", 
        "alpha2": "om", 
        "french": "galla", 
        "bibliographic": "orm", 
        "english": "Oromo"
    }, 
    "que": {
        "terminologic": "", 
        "alpha2": "qu", 
        "french": "quechua", 
        "bibliographic": "que", 
        "english": "Quechua"
    }, 
    "ori": {
        "terminologic": "", 
        "alpha2": "or", 
        "french": "oriya", 
        "bibliographic": "ori", 
        "english": "Oriya"
    }, 
    "crh": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "tatar de Crim\u00e9", 
        "bibliographic": "crh", 
        "english": "Crimean Tatar; Crimean Turkish"
    }, 
    "asm": {
        "terminologic": "", 
        "alpha2": "as", 
        "french": "assamais", 
        "bibliographic": "asm", 
        "english": "Assamese"
    }, 
    "pus": {
        "terminologic": "", 
        "alpha2": "ps", 
        "french": "pachto", 
        "bibliographic": "pus", 
        "english": "Pushto; Pashto"
    }, 
    "dgr": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "dogrib", 
        "bibliographic": "dgr", 
        "english": "Dogrib"
    }, 
    "ltz": {
        "terminologic": "", 
        "alpha2": "lb", 
        "french": "luxembourgeois", 
        "bibliographic": "ltz", 
        "english": "Luxembourgish; Letzeburgesch"
    }, 
    "ath": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "athapascanes, langues", 
        "bibliographic": "ath", 
        "english": "Athapascan languages"
    }, 
    "wln": {
        "terminologic": "", 
        "alpha2": "wa", 
        "french": "wallon", 
        "bibliographic": "wln", 
        "english": "Walloon"
    }, 
    "isl": {
        "terminologic": "isl", 
        "alpha2": "is", 
        "french": "islandais", 
        "bibliographic": "ice", 
        "english": "Icelandic"
    }, 
    "xh": {
        "terminologic": "", 
        "alpha2": "xh", 
        "french": "xhosa", 
        "bibliographic": "xho", 
        "english": "Xhosa"
    }, 
    "mag": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "magahi", 
        "bibliographic": "mag", 
        "english": "Magahi"
    }, 
    "mai": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "maithili", 
        "bibliographic": "mai", 
        "english": "Maithili"
    }, 
    "mah": {
        "terminologic": "", 
        "alpha2": "mh", 
        "french": "marshall", 
        "bibliographic": "mah", 
        "english": "Marshallese"
    }, 
    "tel": {
        "terminologic": "", 
        "alpha2": "te", 
        "french": "t\u00e9lougou", 
        "bibliographic": "tel", 
        "english": "Telugu"
    }, 
    "lav": {
        "terminologic": "", 
        "alpha2": "lv", 
        "french": "letton", 
        "bibliographic": "lav", 
        "english": "Latvian"
    }, 
    "zap": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "zapot\u00e8que", 
        "bibliographic": "zap", 
        "english": "Zapotec"
    }, 
    "yid": {
        "terminologic": "", 
        "alpha2": "yi", 
        "french": "yiddish", 
        "bibliographic": "yid", 
        "english": "Yiddish"
    }, 
    "kok": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "konkani", 
        "bibliographic": "kok", 
        "english": "Konkani"
    }, 
    "kom": {
        "terminologic": "", 
        "alpha2": "kv", 
        "french": "kom", 
        "bibliographic": "kom", 
        "english": "Komi"
    }, 
    "kon": {
        "terminologic": "", 
        "alpha2": "kg", 
        "french": "kongo", 
        "bibliographic": "kon", 
        "english": "Kongo"
    }, 
    "ukr": {
        "terminologic": "", 
        "alpha2": "uk", 
        "french": "ukrainien", 
        "bibliographic": "ukr", 
        "english": "Ukrainian"
    }, 
    "ton": {
        "terminologic": "", 
        "alpha2": "to", 
        "french": "tongan (\u00celes Tonga)", 
        "bibliographic": "ton", 
        "english": "Tonga (Tonga Islands)"
    }, 
    "zxx": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "pas de contenu linguistique; non applicable", 
        "bibliographic": "zxx", 
        "english": "No linguistic content; Not applicable"
    }, 
    "kos": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "kosrae", 
        "bibliographic": "kos", 
        "english": "Kosraean"
    }, 
    "kor": {
        "terminologic": "", 
        "alpha2": "ko", 
        "french": "cor\u00e9en", 
        "bibliographic": "kor", 
        "english": "Korean"
    }, 
    "tog": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "tonga (Nyasa)", 
        "bibliographic": "tog", 
        "english": "Tonga (Nyasa)"
    }, 
    "hun": {
        "terminologic": "", 
        "alpha2": "hu", 
        "french": "hongrois", 
        "bibliographic": "hun", 
        "english": "Hungarian"
    }, 
    "hup": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "hupa", 
        "bibliographic": "hup", 
        "english": "Hupa"
    }, 
    "lug": {
        "terminologic": "", 
        "alpha2": "lg", 
        "french": "ganda", 
        "bibliographic": "lug", 
        "english": "Ganda"
    }, 
    "cym": {
        "terminologic": "cym", 
        "alpha2": "cy", 
        "french": "gallois", 
        "bibliographic": "wel", 
        "english": "Welsh"
    }, 
    "udm": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "oudmourte", 
        "bibliographic": "udm", 
        "english": "Udmurt"
    }, 
    "bej": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "bedja", 
        "bibliographic": "bej", 
        "english": "Beja; Bedawiyet"
    }, 
    "ben": {
        "terminologic": "", 
        "alpha2": "bn", 
        "french": "bengali", 
        "bibliographic": "ben", 
        "english": "Bengali"
    }, 
    "bel": {
        "terminologic": "", 
        "alpha2": "be", 
        "french": "bi\u00e9lorusse", 
        "bibliographic": "bel", 
        "english": "Belarusian"
    }, 
    "bem": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "bemba", 
        "bibliographic": "bem", 
        "english": "Bemba"
    }, 
    "tsi": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "tsimshian", 
        "bibliographic": "tsi", 
        "english": "Tsimshian"
    }, 
    "ber": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "berb\u00e8res, langues", 
        "bibliographic": "ber", 
        "english": "Berber languages"
    }, 
    "nzi": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "nzema", 
        "bibliographic": "nzi", 
        "english": "Nzima"
    }, 
    "sai": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "indiennes d'Am\u00e9rique du Sud, autres langues", 
        "bibliographic": "sai", 
        "english": "South American Indian (Other)"
    }, 
    "ang": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "anglo-saxon (ca.450-1100)", 
        "bibliographic": "ang", 
        "english": "English, Old (ca.450-1100)"
    }, 
    "pra": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "pr\u00e2krit, langues", 
        "bibliographic": "pra", 
        "english": "Prakrit languages"
    }, 
    "san": {
        "terminologic": "", 
        "alpha2": "sa", 
        "french": "sanskrit", 
        "bibliographic": "san", 
        "english": "Sanskrit"
    }, 
    "bho": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "bhojpuri", 
        "bibliographic": "bho", 
        "english": "Bhojpuri"
    }, 
    "sal": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "salishennes, langues", 
        "bibliographic": "sal", 
        "english": "Salishan languages"
    }, 
    "pro": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "proven\u00e7al ancien (jusqu'\u00e0 1500)", 
        "bibliographic": "pro", 
        "english": "Proven\u00e7al, Old (to 1500)"
    }, 
    "raj": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "rajasthani", 
        "bibliographic": "raj", 
        "english": "Rajasthani"
    }, 
    "sad": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "sandawe", 
        "bibliographic": "sad", 
        "english": "Sandawe"
    }, 
    "anp": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "angika", 
        "bibliographic": "anp", 
        "english": "Angika"
    }, 
    "rap": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "rapanui", 
        "bibliographic": "rap", 
        "english": "Rapanui"
    }, 
    "sas": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "sasak", 
        "bibliographic": "sas", 
        "english": "Sasak"
    }, 
    "nqo": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "n'ko", 
        "bibliographic": "nqo", 
        "english": "N'Ko"
    }, 
    "sat": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "santal", 
        "bibliographic": "sat", 
        "english": "Santali"
    }, 
    "min": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "minangkabau", 
        "bibliographic": "min", 
        "english": "Minangkabau"
    }, 
    "lim": {
        "terminologic": "", 
        "alpha2": "li", 
        "french": "limbourgeois", 
        "bibliographic": "lim", 
        "english": "Limburgan; Limburger; Limburgish"
    }, 
    "lin": {
        "terminologic": "", 
        "alpha2": "ln", 
        "french": "lingala", 
        "bibliographic": "lin", 
        "english": "Lingala"
    }, 
    "lit": {
        "terminologic": "", 
        "alpha2": "lt", 
        "french": "lituanien", 
        "bibliographic": "lit", 
        "english": "Lithuanian"
    }, 
    "bur": {
        "terminologic": "mya", 
        "alpha2": "my", 
        "french": "birman", 
        "bibliographic": "bur", 
        "english": "Burmese"
    }, 
    "srn": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "sranan tongo", 
        "bibliographic": "srn", 
        "english": "Sranan Tongo"
    }, 
    "btk": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "batak, langues", 
        "bibliographic": "btk", 
        "english": "Batak languages"
    }, 
    "ypk": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "yupik, langues", 
        "bibliographic": "ypk", 
        "english": "Yupik languages"
    }, 
    "mis": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "langues non cod\u00e9es", 
        "bibliographic": "mis", 
        "english": "Uncoded languages"
    }, 
    "kac": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "kachin; jingpho", 
        "bibliographic": "kac", 
        "english": "Kachin; Jingpho"
    }, 
    "kab": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "kabyle", 
        "bibliographic": "kab", 
        "english": "Kabyle"
    }, 
    "kaa": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "karakalpak", 
        "bibliographic": "kaa", 
        "english": "Kara-Kalpak"
    }, 
    "kan": {
        "terminologic": "", 
        "alpha2": "kn", 
        "french": "kannada", 
        "bibliographic": "kan", 
        "english": "Kannada"
    }, 
    "kam": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "kamba", 
        "bibliographic": "kam", 
        "english": "Kamba"
    }, 
    "kal": {
        "terminologic": "", 
        "alpha2": "kl", 
        "french": "groenlandais", 
        "bibliographic": "kal", 
        "english": "Kalaallisut; Greenlandic"
    }, 
    "kas": {
        "terminologic": "", 
        "alpha2": "ks", 
        "french": "kashmiri", 
        "bibliographic": "kas", 
        "english": "Kashmiri"
    }, 
    "kar": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "karen, langues", 
        "bibliographic": "kar", 
        "english": "Karen languages"
    }, 
    "kaw": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "kawi", 
        "bibliographic": "kaw", 
        "english": "Kawi"
    }, 
    "kau": {
        "terminologic": "", 
        "alpha2": "kr", 
        "french": "kanouri", 
        "bibliographic": "kau", 
        "english": "Kanuri"
    }, 
    "kat": {
        "terminologic": "kat", 
        "alpha2": "ka", 
        "french": "g\u00e9orgien", 
        "bibliographic": "geo", 
        "english": "Georgian"
    }, 
    "kaz": {
        "terminologic": "", 
        "alpha2": "kk", 
        "french": "kazakh", 
        "bibliographic": "kaz", 
        "english": "Kazakh"
    }, 
    "tyv": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "touva", 
        "bibliographic": "tyv", 
        "english": "Tuvinian"
    }, 
    "awa": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "awadhi", 
        "bibliographic": "awa", 
        "english": "Awadhi"
    }, 
    "urd": {
        "terminologic": "", 
        "alpha2": "ur", 
        "french": "ourdou", 
        "bibliographic": "urd", 
        "english": "Urdu"
    }, 
    "ka": {
        "terminologic": "kat", 
        "alpha2": "ka", 
        "french": "g\u00e9orgien", 
        "bibliographic": "geo", 
        "english": "Georgian"
    }, 
    "doi": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "dogri", 
        "bibliographic": "doi", 
        "english": "Dogri"
    }, 
    "kg": {
        "terminologic": "", 
        "alpha2": "kg", 
        "french": "kongo", 
        "bibliographic": "kon", 
        "english": "Kongo"
    }, 
    "kk": {
        "terminologic": "", 
        "alpha2": "kk", 
        "french": "kazakh", 
        "bibliographic": "kaz", 
        "english": "Kazakh"
    }, 
    "kj": {
        "terminologic": "", 
        "alpha2": "kj", 
        "french": "kuanyama; kwanyama", 
        "bibliographic": "kua", 
        "english": "Kuanyama; Kwanyama"
    }, 
    "ki": {
        "terminologic": "", 
        "alpha2": "ki", 
        "french": "kikuyu", 
        "bibliographic": "kik", 
        "english": "Kikuyu; Gikuyu"
    }, 
    "ko": {
        "terminologic": "", 
        "alpha2": "ko", 
        "french": "cor\u00e9en", 
        "bibliographic": "kor", 
        "english": "Korean"
    }, 
    "kn": {
        "terminologic": "", 
        "alpha2": "kn", 
        "french": "kannada", 
        "bibliographic": "kan", 
        "english": "Kannada"
    }, 
    "km": {
        "terminologic": "", 
        "alpha2": "km", 
        "french": "khmer central", 
        "bibliographic": "khm", 
        "english": "Central Khmer"
    }, 
    "kl": {
        "terminologic": "", 
        "alpha2": "kl", 
        "french": "groenlandais", 
        "bibliographic": "kal", 
        "english": "Kalaallisut; Greenlandic"
    }, 
    "ks": {
        "terminologic": "", 
        "alpha2": "ks", 
        "french": "kashmiri", 
        "bibliographic": "kas", 
        "english": "Kashmiri"
    }, 
    "kr": {
        "terminologic": "", 
        "alpha2": "kr", 
        "french": "kanouri", 
        "bibliographic": "kau", 
        "english": "Kanuri"
    }, 
    "kw": {
        "terminologic": "", 
        "alpha2": "kw", 
        "french": "cornique", 
        "bibliographic": "cor", 
        "english": "Cornish"
    }, 
    "kv": {
        "terminologic": "", 
        "alpha2": "kv", 
        "french": "kom", 
        "bibliographic": "kom", 
        "english": "Komi"
    }, 
    "ku": {
        "terminologic": "", 
        "alpha2": "ku", 
        "french": "kurde", 
        "bibliographic": "kur", 
        "english": "Kurdish"
    }, 
    "ky": {
        "terminologic": "", 
        "alpha2": "ky", 
        "french": "kirghiz", 
        "bibliographic": "kir", 
        "english": "Kirghiz; Kyrgyz"
    }, 
    "kut": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "kutenai", 
        "bibliographic": "kut", 
        "english": "Kutenai"
    }, 
    "tkl": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "tokelau", 
        "bibliographic": "tkl", 
        "english": "Tokelau"
    }, 
    "nld": {
        "terminologic": "nld", 
        "alpha2": "nl", 
        "french": "n\u00e9erlandais; flamand", 
        "bibliographic": "dut", 
        "english": "Dutch; Flemish"
    }, 
    "oji": {
        "terminologic": "", 
        "alpha2": "oj", 
        "french": "ojibwa", 
        "bibliographic": "oji", 
        "english": "Ojibwa"
    }, 
    "oci": {
        "terminologic": "", 
        "alpha2": "oc", 
        "french": "occitan (apr\u00e8s 1500); proven\u00e7al", 
        "bibliographic": "oci", 
        "english": "Occitan (post 1500); Proven\u00e7al"
    }, 
    "bua": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "bouriate", 
        "bibliographic": "bua", 
        "english": "Buriat"
    }, 
    "wol": {
        "terminologic": "", 
        "alpha2": "wo", 
        "french": "wolof", 
        "bibliographic": "wol", 
        "english": "Wolof"
    }, 
    "jav": {
        "terminologic": "", 
        "alpha2": "jv", 
        "french": "javanais", 
        "bibliographic": "jav", 
        "english": "Javanese"
    }, 
    "hrv": {
        "terminologic": "", 
        "alpha2": "hr", 
        "french": "croate", 
        "bibliographic": "hrv", 
        "english": "Croatian"
    }, 
    "zza": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "zaza; dimili; dimli; kirdki; kirmanjki; zazaki", 
        "bibliographic": "zza", 
        "english": "Zaza; Dimili; Dimli; Kirdki; Kirmanjki; Zazaki"
    }, 
    "ger": {
        "terminologic": "deu", 
        "alpha2": "de", 
        "french": "allemand", 
        "bibliographic": "ger", 
        "english": "German"
    }, 
    "mga": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "irlandais moyen (900-1200)", 
        "bibliographic": "mga", 
        "english": "Irish, Middle (900-1200)"
    }, 
    "hit": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "hittite", 
        "bibliographic": "hit", 
        "english": "Hittite"
    }, 
    "dyu": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "dioula", 
        "bibliographic": "dyu", 
        "english": "Dyula"
    }, 
    "ssw": {
        "terminologic": "", 
        "alpha2": "ss", 
        "french": "swati", 
        "bibliographic": "ssw", 
        "english": "Swati"
    }, 
    "de": {
        "terminologic": "deu", 
        "alpha2": "de", 
        "french": "allemand", 
        "bibliographic": "ger", 
        "english": "German"
    }, 
    "da": {
        "terminologic": "", 
        "alpha2": "da", 
        "french": "danois", 
        "bibliographic": "dan", 
        "english": "Danish"
    }, 
    "dz": {
        "terminologic": "", 
        "alpha2": "dz", 
        "french": "dzongkha", 
        "bibliographic": "dzo", 
        "english": "Dzongkha"
    }, 
    "lui": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "luiseno", 
        "bibliographic": "lui", 
        "english": "Luiseno"
    }, 
    "dv": {
        "terminologic": "", 
        "alpha2": "dv", 
        "french": "maldivien", 
        "bibliographic": "div", 
        "english": "Divehi; Dhivehi; Maldivian"
    }, 
    "hil": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "hiligaynon", 
        "bibliographic": "hil", 
        "english": "Hiligaynon"
    }, 
    "him": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "langues himachalis; langues paharis occidentales", 
        "bibliographic": "him", 
        "english": "Himachali languages; Western Pahari languages"
    }, 
    "hin": {
        "terminologic": "", 
        "alpha2": "hi", 
        "french": "hindi", 
        "bibliographic": "hin", 
        "english": "Hindi"
    }, 
    "crp": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "cr\u00e9oles et pidgins", 
        "bibliographic": "crp", 
        "english": "Creoles and pidgins "
    }, 
    "myn": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "maya, langues", 
        "bibliographic": "myn", 
        "english": "Mayan languages"
    }, 
    "bas": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "basa", 
        "bibliographic": "bas", 
        "english": "Basa"
    }, 
    "baq": {
        "terminologic": "eus", 
        "alpha2": "eu", 
        "french": "basque", 
        "bibliographic": "baq", 
        "english": "Basque"
    }, 
    "bad": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "banda, langues", 
        "bibliographic": "bad", 
        "english": "Banda languages"
    }, 
    "nep": {
        "terminologic": "", 
        "alpha2": "ne", 
        "french": "n\u00e9palais", 
        "bibliographic": "nep", 
        "english": "Nepali"
    }, 
    "cre": {
        "terminologic": "", 
        "alpha2": "cr", 
        "french": "cree", 
        "bibliographic": "cre", 
        "english": "Cree"
    }, 
    "ban": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "balinais", 
        "bibliographic": "ban", 
        "english": "Balinese"
    }, 
    "bal": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "baloutchi", 
        "bibliographic": "bal", 
        "english": "Baluchi"
    }, 
    "bam": {
        "terminologic": "", 
        "alpha2": "bm", 
        "french": "bambara", 
        "bibliographic": "bam", 
        "english": "Bambara"
    }, 
    "bak": {
        "terminologic": "", 
        "alpha2": "ba", 
        "french": "bachkir", 
        "bibliographic": "bak", 
        "english": "Bashkir"
    }, 
    "shn": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "chan", 
        "bibliographic": "shn", 
        "english": "Shan"
    }, 
    "bai": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "bamil\u00e9k\u00e9, langues", 
        "bibliographic": "bai", 
        "english": "Bamileke languages"
    }, 
    "arp": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "arapaho", 
        "bibliographic": "arp", 
        "english": "Arapaho"
    }, 
    "art": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "artificielles, langues", 
        "bibliographic": "art", 
        "english": "Artificial languages"
    }, 
    "arw": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "arawak", 
        "bibliographic": "arw", 
        "english": "Arawak"
    }, 
    "ara": {
        "terminologic": "", 
        "alpha2": "ar", 
        "french": "arabe", 
        "bibliographic": "ara", 
        "english": "Arabic"
    }, 
    "arc": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "aram\u00e9en d'empire (700-300 BCE)", 
        "bibliographic": "arc", 
        "english": "Official Aramaic (700-300 BCE); Imperial Aramaic (700-300 BCE)"
    }, 
    "arg": {
        "terminologic": "", 
        "alpha2": "an", 
        "french": "aragonais", 
        "bibliographic": "arg", 
        "english": "Aragonese"
    }, 
    "sem": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "s\u00e9mitiques, langues", 
        "bibliographic": "sem", 
        "english": "Semitic languages"
    }, 
    "sel": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "selkoupe", 
        "bibliographic": "sel", 
        "english": "Selkup"
    }, 
    "nub": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "nubiennes, langues", 
        "bibliographic": "nub", 
        "english": "Nubian languages"
    }, 
    "arm": {
        "terminologic": "hye", 
        "alpha2": "hy", 
        "french": "arm\u00e9nien", 
        "bibliographic": "arm", 
        "english": "Armenian"
    }, 
    "arn": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "mapudungun; mapuche; mapuce", 
        "bibliographic": "arn", 
        "english": "Mapudungun; Mapuche"
    }, 
    "lus": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "lushai", 
        "bibliographic": "lus", 
        "english": "Lushai"
    }, 
    "wa": {
        "terminologic": "", 
        "alpha2": "wa", 
        "french": "wallon", 
        "bibliographic": "wln", 
        "english": "Walloon"
    }, 
    "mus": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "muskogee", 
        "bibliographic": "mus", 
        "english": "Creek"
    }, 
    "lua": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "luba-lulua", 
        "bibliographic": "lua", 
        "english": "Luba-Lulua"
    }, 
    "lub": {
        "terminologic": "", 
        "alpha2": "lu", 
        "french": "luba-katanga", 
        "bibliographic": "lub", 
        "english": "Luba-Katanga"
    }, 
    "iro": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "iroquoises, langues", 
        "bibliographic": "iro", 
        "english": "Iroquoian languages"
    }, 
    "ira": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "iraniennes, langues", 
        "bibliographic": "ira", 
        "english": "Iranian languages"
    }, 
    "mun": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "mounda, langues", 
        "bibliographic": "mun", 
        "english": "Munda languages"
    }, 
    "tur": {
        "terminologic": "", 
        "alpha2": "tr", 
        "french": "turc", 
        "bibliographic": "tur", 
        "english": "Turkish"
    }, 
    "lun": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "lunda", 
        "bibliographic": "lun", 
        "english": "Lunda"
    }, 
    "luo": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "luo (Kenya et Tanzanie)", 
        "bibliographic": "luo", 
        "english": "Luo (Kenya and Tanzania)"
    }, 
    "iku": {
        "terminologic": "", 
        "alpha2": "iu", 
        "french": "inuktitut", 
        "bibliographic": "iku", 
        "english": "Inuktitut"
    }, 
    "tso": {
        "terminologic": "", 
        "alpha2": "ts", 
        "french": "tsonga", 
        "bibliographic": "tso", 
        "english": "Tsonga"
    }, 
    "tup": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "tupi, langues", 
        "bibliographic": "tup", 
        "english": "Tupi languages"
    }, 
    "jv": {
        "terminologic": "", 
        "alpha2": "jv", 
        "french": "javanais", 
        "bibliographic": "jav", 
        "english": "Javanese"
    }, 
    "zbl": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "symboles Bliss; Bliss", 
        "bibliographic": "zbl", 
        "english": "Blissymbols; Blissymbolics; Bliss"
    }, 
    "tut": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "alta\u00efques, langues", 
        "bibliographic": "tut", 
        "english": "Altaic languages"
    }, 
    "tuk": {
        "terminologic": "", 
        "alpha2": "tk", 
        "french": "turkm\u00e8ne", 
        "bibliographic": "tuk", 
        "english": "Turkmen"
    }, 
    "tum": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "tumbuka", 
        "bibliographic": "tum", 
        "english": "Tumbuka"
    }, 
    "ja": {
        "terminologic": "", 
        "alpha2": "ja", 
        "french": "japonais", 
        "bibliographic": "jpn", 
        "english": "Japanese"
    }, 
    "cop": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "copte", 
        "bibliographic": "cop", 
        "english": "Coptic"
    }, 
    "cos": {
        "terminologic": "", 
        "alpha2": "co", 
        "french": "corse", 
        "bibliographic": "cos", 
        "english": "Corsican"
    }, 
    "cor": {
        "terminologic": "", 
        "alpha2": "kw", 
        "french": "cornique", 
        "bibliographic": "cor", 
        "english": "Cornish"
    }, 
    "ilo": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "ilocano", 
        "bibliographic": "ilo", 
        "english": "Iloko"
    }, 
    "la": {
        "terminologic": "", 
        "alpha2": "la", 
        "french": "latin", 
        "bibliographic": "lat", 
        "english": "Latin"
    }, 
    "gwi": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "gwich'in", 
        "bibliographic": "gwi", 
        "english": "Gwich'in"
    }, 
    "und": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "ind\u00e9termin\u00e9e", 
        "bibliographic": "und", 
        "english": "Undetermined"
    }, 
    "lo": {
        "terminologic": "", 
        "alpha2": "lo", 
        "french": "lao", 
        "bibliographic": "lao", 
        "english": "Lao"
    }, 
    "tli": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "tlingit", 
        "bibliographic": "tli", 
        "english": "Tlingit"
    }, 
    "tlh": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "klingon", 
        "bibliographic": "tlh", 
        "english": "Klingon; tlhIngan-Hol"
    }, 
    "nno": {
        "terminologic": "", 
        "alpha2": "nn", 
        "french": "norv\u00e9gien nynorsk; nynorsk, norv\u00e9gien", 
        "bibliographic": "nno", 
        "english": "Norwegian Nynorsk; Nynorsk, Norwegian"
    }, 
    "ch": {
        "terminologic": "", 
        "alpha2": "ch", 
        "french": "chamorro", 
        "bibliographic": "cha", 
        "english": "Chamorro"
    }, 
    "co": {
        "terminologic": "", 
        "alpha2": "co", 
        "french": "corse", 
        "bibliographic": "cos", 
        "english": "Corsican"
    }, 
    "ca": {
        "terminologic": "", 
        "alpha2": "ca", 
        "french": "catalan; valencien", 
        "bibliographic": "cat", 
        "english": "Catalan; Valencian"
    }, 
    "por": {
        "terminologic": "", 
        "alpha2": "pt", 
        "french": "portugais", 
        "bibliographic": "por", 
        "english": "Portuguese"
    }, 
    "ce": {
        "terminologic": "", 
        "alpha2": "ce", 
        "french": "tch\u00e9tch\u00e8ne", 
        "bibliographic": "che", 
        "english": "Chechen"
    }, 
    "pon": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "pohnpei", 
        "bibliographic": "pon", 
        "english": "Pohnpeian"
    }, 
    "pol": {
        "terminologic": "", 
        "alpha2": "pl", 
        "french": "polonais", 
        "bibliographic": "pol", 
        "english": "Polish"
    }, 
    "sah": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "iakoute", 
        "bibliographic": "sah", 
        "english": "Yakut"
    }, 
    "cs": {
        "terminologic": "ces", 
        "alpha2": "cs", 
        "french": "tch\u00e8que", 
        "bibliographic": "cze", 
        "english": "Czech"
    }, 
    "cr": {
        "terminologic": "", 
        "alpha2": "cr", 
        "french": "cree", 
        "bibliographic": "cre", 
        "english": "Cree"
    }, 
    "bnt": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "bantoues, autres langues", 
        "bibliographic": "bnt", 
        "english": "Bantu (Other)"
    }, 
    "cv": {
        "terminologic": "", 
        "alpha2": "cv", 
        "french": "tchouvache", 
        "bibliographic": "chv", 
        "english": "Chuvash"
    }, 
    "cu": {
        "terminologic": "", 
        "alpha2": "cu", 
        "french": "slavon d'\u00e9glise; vieux slave; slavon liturgique; vieux bulgare", 
        "bibliographic": "chu", 
        "english": "Church Slavic; Old Slavonic; Church Slavonic; Old Bulgarian; Old Church Slavonic"
    }, 
    "lv": {
        "terminologic": "", 
        "alpha2": "lv", 
        "french": "letton", 
        "bibliographic": "lav", 
        "english": "Latvian"
    }, 
    "fra": {
        "terminologic": "fra", 
        "alpha2": "fr", 
        "french": "fran\u00e7ais", 
        "bibliographic": "fre", 
        "english": "French"
    }, 
    "dum": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "n\u00e9erlandais moyen (ca. 1050-1350)", 
        "bibliographic": "dum", 
        "english": "Dutch, Middle (ca.1050-1350)"
    }, 
    "fre": {
        "terminologic": "fra", 
        "alpha2": "fr", 
        "french": "fran\u00e7ais", 
        "bibliographic": "fre", 
        "english": "French"
    }, 
    "swa": {
        "terminologic": "", 
        "alpha2": "sw", 
        "french": "swahili", 
        "bibliographic": "swa", 
        "english": "Swahili"
    }, 
    "dua": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "douala", 
        "bibliographic": "dua", 
        "english": "Duala"
    }, 
    "fro": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "fran\u00e7ais ancien (842-ca.1400)", 
        "bibliographic": "fro", 
        "english": "French, Old (842-ca.1400)"
    }, 
    "yap": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "yapois", 
        "bibliographic": "yap", 
        "english": "Yapese"
    }, 
    "frm": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "fran\u00e7ais moyen (1400-1600)", 
        "bibliographic": "frm", 
        "english": "French, Middle (ca.1400-1600)"
    }, 
    "nb": {
        "terminologic": "", 
        "alpha2": "nb", 
        "french": "norv\u00e9gien bokm\u00e5l", 
        "bibliographic": "nob", 
        "english": "Bokm\u00e5l, Norwegian; Norwegian Bokm\u00e5l"
    }, 
    "frs": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "frison oriental", 
        "bibliographic": "frs", 
        "english": "Eastern Frisian"
    }, 
    "frr": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "frison septentrional", 
        "bibliographic": "frr", 
        "english": "Northern Frisian"
    }, 
    "yao": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "yao", 
        "bibliographic": "yao", 
        "english": "Yao"
    }, 
    "pa": {
        "terminologic": "", 
        "alpha2": "pa", 
        "french": "pendjabi", 
        "bibliographic": "pan", 
        "english": "Panjabi; Punjabi"
    }, 
    "xal": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "kalmouk; o\u00efrat", 
        "bibliographic": "xal", 
        "english": "Kalmyk; Oirat"
    }, 
    "fry": {
        "terminologic": "", 
        "alpha2": "fy", 
        "french": "frison occidental", 
        "bibliographic": "fry", 
        "english": "Western Frisian"
    }, 
    "pi": {
        "terminologic": "", 
        "alpha2": "pi", 
        "french": "pali", 
        "bibliographic": "pli", 
        "english": "Pali"
    }, 
    "dut": {
        "terminologic": "nld", 
        "alpha2": "nl", 
        "french": "n\u00e9erlandais; flamand", 
        "bibliographic": "dut", 
        "english": "Dutch; Flemish"
    }, 
    "pl": {
        "terminologic": "", 
        "alpha2": "pl", 
        "french": "polonais", 
        "bibliographic": "pol", 
        "english": "Polish"
    }, 
    "gay": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "gayo", 
        "bibliographic": "gay", 
        "english": "Gayo"
    }, 
    "oto": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "otomi, langues", 
        "bibliographic": "oto", 
        "english": "Otomian languages"
    }, 
    "ota": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "turc ottoman (1500-1928)", 
        "bibliographic": "ota", 
        "english": "Turkish, Ottoman (1500-1928)"
    }, 
    "hmn": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "hmong", 
        "bibliographic": "hmn", 
        "english": "Hmong; Mong"
    }, 
    "ile": {
        "terminologic": "", 
        "alpha2": "ie", 
        "french": "interlingue", 
        "bibliographic": "ile", 
        "english": "Interlingue; Occidental"
    }, 
    "myv": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "erza", 
        "bibliographic": "myv", 
        "english": "Erzya"
    }, 
    "gaa": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "ga", 
        "bibliographic": "gaa", 
        "english": "Ga"
    }, 
    "fur": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "frioulan", 
        "bibliographic": "fur", 
        "english": "Friulian"
    }, 
    "mlg": {
        "terminologic": "", 
        "alpha2": "mg", 
        "french": "malgache", 
        "bibliographic": "mlg", 
        "english": "Malagasy"
    }, 
    "slv": {
        "terminologic": "", 
        "alpha2": "sl", 
        "french": "slov\u00e8ne", 
        "bibliographic": "slv", 
        "english": "Slovenian"
    }, 
    "ain": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "a\u00efnou", 
        "bibliographic": "ain", 
        "english": "Ainu"
    }, 
    "fil": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "filipino; pilipino", 
        "bibliographic": "fil", 
        "english": "Filipino; Pilipino"
    }, 
    "mlt": {
        "terminologic": "", 
        "alpha2": "mt", 
        "french": "maltais", 
        "bibliographic": "mlt", 
        "english": "Maltese"
    }, 
    "slk": {
        "terminologic": "slk", 
        "alpha2": "sk", 
        "french": "slovaque", 
        "bibliographic": "slo", 
        "english": "Slovak"
    }, 
    "rar": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "rarotonga; maori des \u00eeles Cook", 
        "bibliographic": "rar", 
        "english": "Rarotongan; Cook Islands Maori"
    }, 
    "ful": {
        "terminologic": "", 
        "alpha2": "ff", 
        "french": "peul", 
        "bibliographic": "ful", 
        "english": "Fulah"
    }, 
    "sla": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "slaves, langues", 
        "bibliographic": "sla", 
        "english": "Slavic languages"
    }, 
    "ve": {
        "terminologic": "", 
        "alpha2": "ve", 
        "french": "venda", 
        "bibliographic": "ven", 
        "english": "Venda"
    }, 
    "jpn": {
        "terminologic": "", 
        "alpha2": "ja", 
        "french": "japonais", 
        "bibliographic": "jpn", 
        "english": "Japanese"
    }, 
    "vol": {
        "terminologic": "", 
        "alpha2": "vo", 
        "french": "volap\u00fck", 
        "bibliographic": "vol", 
        "english": "Volap\u00fck"
    }, 
    "vi": {
        "terminologic": "", 
        "alpha2": "vi", 
        "french": "vietnamien", 
        "bibliographic": "vie", 
        "english": "Vietnamese"
    }, 
    "is": {
        "terminologic": "isl", 
        "alpha2": "is", 
        "french": "islandais", 
        "bibliographic": "ice", 
        "english": "Icelandic"
    }, 
    "av": {
        "terminologic": "", 
        "alpha2": "av", 
        "french": "avar", 
        "bibliographic": "ava", 
        "english": "Avaric"
    }, 
    "iu": {
        "terminologic": "", 
        "alpha2": "iu", 
        "french": "inuktitut", 
        "bibliographic": "iku", 
        "english": "Inuktitut"
    }, 
    "it": {
        "terminologic": "", 
        "alpha2": "it", 
        "french": "italien", 
        "bibliographic": "ita", 
        "english": "Italian"
    }, 
    "vo": {
        "terminologic": "", 
        "alpha2": "vo", 
        "french": "volap\u00fck", 
        "bibliographic": "vol", 
        "english": "Volap\u00fck"
    }, 
    "ii": {
        "terminologic": "", 
        "alpha2": "ii", 
        "french": "yi de Sichuan", 
        "bibliographic": "iii", 
        "english": "Sichuan Yi; Nuosu"
    }, 
    "mya": {
        "terminologic": "mya", 
        "alpha2": "my", 
        "french": "birman", 
        "bibliographic": "bur", 
        "english": "Burmese"
    }, 
    "ik": {
        "terminologic": "", 
        "alpha2": "ik", 
        "french": "inupiaq", 
        "bibliographic": "ipk", 
        "english": "Inupiaq"
    }, 
    "io": {
        "terminologic": "", 
        "alpha2": "io", 
        "french": "ido", 
        "bibliographic": "ido", 
        "english": "Ido"
    }, 
    "ine": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "indo-europ\u00e9ennes, langues", 
        "bibliographic": "ine", 
        "english": "Indo-European languages"
    }, 
    "ia": {
        "terminologic": "", 
        "alpha2": "ia", 
        "french": "interlingua (langue auxiliaire internationale)", 
        "bibliographic": "ina", 
        "english": "Interlingua (International Auxiliary Language Association)"
    }, 
    "ave": {
        "terminologic": "", 
        "alpha2": "ae", 
        "french": "avestique", 
        "bibliographic": "ave", 
        "english": "Avestan"
    }, 
    "jpr": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "jud\u00e9o-persan", 
        "bibliographic": "jpr", 
        "english": "Judeo-Persian"
    }, 
    "ie": {
        "terminologic": "", 
        "alpha2": "ie", 
        "french": "interlingue", 
        "bibliographic": "ile", 
        "english": "Interlingue; Occidental"
    }, 
    "id": {
        "terminologic": "", 
        "alpha2": "id", 
        "french": "indon\u00e9sien", 
        "bibliographic": "ind", 
        "english": "Indonesian"
    }, 
    "ig": {
        "terminologic": "", 
        "alpha2": "ig", 
        "french": "igbo", 
        "bibliographic": "ibo", 
        "english": "Igbo"
    }, 
    "pap": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "papiamento", 
        "bibliographic": "pap", 
        "english": "Papiamento"
    }, 
    "ewo": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "\u00e9wondo", 
        "bibliographic": "ewo", 
        "english": "Ewondo"
    }, 
    "pau": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "palau", 
        "bibliographic": "pau", 
        "english": "Palauan"
    }, 
    "ewe": {
        "terminologic": "", 
        "alpha2": "ee", 
        "french": "\u00e9w\u00e9", 
        "bibliographic": "ewe", 
        "english": "Ewe"
    }, 
    "zgh": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "amazighe standard marocain", 
        "bibliographic": "zgh", 
        "english": "Standard Moroccan Tamazight"
    }, 
    "paa": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "papoues, langues", 
        "bibliographic": "paa", 
        "english": "Papuan languages"
    }, 
    "pag": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "pangasinan", 
        "bibliographic": "pag", 
        "english": "Pangasinan"
    }, 
    "pal": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "pahlavi", 
        "bibliographic": "pal", 
        "english": "Pahlavi"
    }, 
    "pam": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "pampangan", 
        "bibliographic": "pam", 
        "english": "Pampanga; Kapampangan"
    }, 
    "pan": {
        "terminologic": "", 
        "alpha2": "pa", 
        "french": "pendjabi", 
        "bibliographic": "pan", 
        "english": "Panjabi; Punjabi"
    }, 
    "syc": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "syriaque classique", 
        "bibliographic": "syc", 
        "english": "Classical Syriac"
    }, 
    "phi": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "philippines, langues", 
        "bibliographic": "phi", 
        "english": "Philippine languages"
    }, 
    "nog": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "noga\u00ef; nogay", 
        "bibliographic": "nog", 
        "english": "Nogai"
    }, 
    "phn": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "ph\u00e9nicien", 
        "bibliographic": "phn", 
        "english": "Phoenician"
    }, 
    "kir": {
        "terminologic": "", 
        "alpha2": "ky", 
        "french": "kirghiz", 
        "bibliographic": "kir", 
        "english": "Kirghiz; Kyrgyz"
    }, 
    "nia": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "nias", 
        "bibliographic": "nia", 
        "english": "Nias"
    }, 
    "kik": {
        "terminologic": "", 
        "alpha2": "ki", 
        "french": "kikuyu", 
        "bibliographic": "kik", 
        "english": "Kikuyu; Gikuyu"
    }, 
    "syr": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "syriaque", 
        "bibliographic": "syr", 
        "english": "Syriac"
    }, 
    "kin": {
        "terminologic": "", 
        "alpha2": "rw", 
        "french": "rwanda", 
        "bibliographic": "kin", 
        "english": "Kinyarwanda"
    }, 
    "niu": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "niu\u00e9", 
        "bibliographic": "niu", 
        "english": "Niuean"
    }, 
    "gsw": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "suisse al\u00e9manique; al\u00e9manique; alsacien", 
        "bibliographic": "gsw", 
        "english": "Swiss German; Alemannic; Alsatian"
    }, 
    "epo": {
        "terminologic": "", 
        "alpha2": "eo", 
        "french": "esp\u00e9ranto", 
        "bibliographic": "epo", 
        "english": "Esperanto"
    }, 
    "jbo": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "lojban", 
        "bibliographic": "jbo", 
        "english": "Lojban"
    }, 
    "mic": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "mi'kmaq; micmac", 
        "bibliographic": "mic", 
        "english": "Mi'kmaq; Micmac"
    }, 
    "tha": {
        "terminologic": "", 
        "alpha2": "th", 
        "french": "tha\u00ef", 
        "bibliographic": "tha", 
        "english": "Thai"
    }, 
    "sam": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "samaritain", 
        "bibliographic": "sam", 
        "english": "Samaritan Aramaic"
    }, 
    "hai": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "haida", 
        "bibliographic": "hai", 
        "english": "Haida"
    }, 
    "gmh": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "allemand, moyen haut (ca. 1050-1500)", 
        "bibliographic": "gmh", 
        "english": "German, Middle High (ca.1050-1500)"
    }, 
    "cus": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "couchitiques, langues", 
        "bibliographic": "cus", 
        "english": "Cushitic languages"
    }, 
    "ell": {
        "terminologic": "ell", 
        "alpha2": "el", 
        "french": "grec moderne (apr\u00e8s 1453)", 
        "bibliographic": "gre", 
        "english": "Greek, Modern (1453-)"
    }, 
    "efi": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "efik", 
        "bibliographic": "efi", 
        "english": "Efik"
    }, 
    "wen": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "sorabes, langues", 
        "bibliographic": "wen", 
        "english": "Sorbian languages"
    }, 
    "ady": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "adygh\u00e9", 
        "bibliographic": "ady", 
        "english": "Adyghe; Adygei"
    }, 
    "elx": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "\u00e9lamite", 
        "bibliographic": "elx", 
        "english": "Elamite"
    }, 
    "ada": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "adangme", 
        "bibliographic": "ada", 
        "english": "Adangme"
    }, 
    "nav": {
        "terminologic": "", 
        "alpha2": "nv", 
        "french": "navaho", 
        "bibliographic": "nav", 
        "english": "Navajo; Navaho"
    }, 
    "hat": {
        "terminologic": "", 
        "alpha2": "ht", 
        "french": "ha\u00eftien; cr\u00e9ole ha\u00eftien", 
        "bibliographic": "hat", 
        "english": "Haitian; Haitian Creole"
    }, 
    "hau": {
        "terminologic": "", 
        "alpha2": "ha", 
        "french": "haoussa", 
        "bibliographic": "hau", 
        "english": "Hausa"
    }, 
    "haw": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "hawa\u00efen", 
        "bibliographic": "haw", 
        "english": "Hawaiian"
    }, 
    "bin": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "bini; edo", 
        "bibliographic": "bin", 
        "english": "Bini; Edo"
    }, 
    "amh": {
        "terminologic": "", 
        "alpha2": "am", 
        "french": "amharique", 
        "bibliographic": "amh", 
        "english": "Amharic"
    }, 
    "bik": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "bikol", 
        "bibliographic": "bik", 
        "english": "Bikol"
    }, 
    "bih": {
        "terminologic": "", 
        "alpha2": "bh", 
        "french": "langues biharis", 
        "bibliographic": "bih", 
        "english": "Bihari languages"
    }, 
    "mos": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "mor\u00e9", 
        "bibliographic": "mos", 
        "english": "Mossi"
    }, 
    "moh": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "mohawk", 
        "bibliographic": "moh", 
        "english": "Mohawk"
    }, 
    "mon": {
        "terminologic": "", 
        "alpha2": "mn", 
        "french": "mongol", 
        "bibliographic": "mon", 
        "english": "Mongolian"
    }, 
    "bis": {
        "terminologic": "", 
        "alpha2": "bi", 
        "french": "bichlamar", 
        "bibliographic": "bis", 
        "english": "Bislama"
    }, 
    "bla": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "blackfoot", 
        "bibliographic": "bla", 
        "english": "Siksika"
    }, 
    "cy": {
        "terminologic": "cym", 
        "alpha2": "cy", 
        "french": "gallois", 
        "bibliographic": "wel", 
        "english": "Welsh"
    }, 
    "tib": {
        "terminologic": "bod", 
        "alpha2": "bo", 
        "french": "tib\u00e9tain", 
        "bibliographic": "tib", 
        "english": "Tibetan"
    }, 
    "tvl": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "tuvalu", 
        "bibliographic": "tvl", 
        "english": "Tuvalu"
    }, 
    "tgk": {
        "terminologic": "", 
        "alpha2": "tg", 
        "french": "tadjik", 
        "bibliographic": "tgk", 
        "english": "Tajik"
    }, 
    "ijo": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "ijo, langues", 
        "bibliographic": "ijo", 
        "english": "Ijo languages"
    }, 
    "est": {
        "terminologic": "", 
        "alpha2": "et", 
        "french": "estonien", 
        "bibliographic": "est", 
        "english": "Estonian"
    }, 
    "kmb": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "kimbundu", 
        "bibliographic": "kmb", 
        "english": "Kimbundu"
    }, 
    "ice": {
        "terminologic": "isl", 
        "alpha2": "is", 
        "french": "islandais", 
        "bibliographic": "ice", 
        "english": "Icelandic"
    }, 
    "peo": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "perse, vieux (ca. 600-400 av. J.-C.)", 
        "bibliographic": "peo", 
        "english": "Persian, Old (ca.600-400 B.C.)"
    }, 
    "tl": {
        "terminologic": "", 
        "alpha2": "tl", 
        "french": "tagalog", 
        "bibliographic": "tgl", 
        "english": "Tagalog"
    }, 
    "tgl": {
        "terminologic": "", 
        "alpha2": "tl", 
        "french": "tagalog", 
        "bibliographic": "tgl", 
        "english": "Tagalog"
    }, 
    "umb": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "umbundu", 
        "bibliographic": "umb", 
        "english": "Umbundu"
    }, 
    "tmh": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "tamacheq", 
        "bibliographic": "tmh", 
        "english": "Tamashek"
    }, 
    "fon": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "fon", 
        "bibliographic": "fon", 
        "english": "Fon"
    }, 
    "hsb": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "haut-sorabe", 
        "bibliographic": "hsb", 
        "english": "Upper Sorbian"
    }, 
    "be": {
        "terminologic": "", 
        "alpha2": "be", 
        "french": "bi\u00e9lorusse", 
        "bibliographic": "bel", 
        "english": "Belarusian"
    }, 
    "bg": {
        "terminologic": "", 
        "alpha2": "bg", 
        "french": "bulgare", 
        "bibliographic": "bul", 
        "english": "Bulgarian"
    }, 
    "run": {
        "terminologic": "", 
        "alpha2": "rn", 
        "french": "rundi", 
        "bibliographic": "run", 
        "english": "Rundi"
    }, 
    "ba": {
        "terminologic": "", 
        "alpha2": "ba", 
        "french": "bachkir", 
        "bibliographic": "bak", 
        "english": "Bashkir"
    }, 
    "ps": {
        "terminologic": "", 
        "alpha2": "ps", 
        "french": "pachto", 
        "bibliographic": "pus", 
        "english": "Pushto; Pashto"
    }, 
    "bm": {
        "terminologic": "", 
        "alpha2": "bm", 
        "french": "bambara", 
        "bibliographic": "bam", 
        "english": "Bambara"
    }, 
    "bn": {
        "terminologic": "", 
        "alpha2": "bn", 
        "french": "bengali", 
        "bibliographic": "ben", 
        "english": "Bengali"
    }, 
    "bo": {
        "terminologic": "bod", 
        "alpha2": "bo", 
        "french": "tib\u00e9tain", 
        "bibliographic": "tib", 
        "english": "Tibetan"
    }, 
    "bh": {
        "terminologic": "", 
        "alpha2": "bh", 
        "french": "langues biharis", 
        "bibliographic": "bih", 
        "english": "Bihari languages"
    }, 
    "bi": {
        "terminologic": "", 
        "alpha2": "bi", 
        "french": "bichlamar", 
        "bibliographic": "bis", 
        "english": "Bislama"
    }, 
    "sag": {
        "terminologic": "", 
        "alpha2": "sg", 
        "french": "sango", 
        "bibliographic": "sag", 
        "english": "Sango"
    }, 
    "br": {
        "terminologic": "", 
        "alpha2": "br", 
        "french": "breton", 
        "bibliographic": "bre", 
        "english": "Breton"
    }, 
    "bs": {
        "terminologic": "", 
        "alpha2": "bs", 
        "french": "bosniaque", 
        "bibliographic": "bos", 
        "english": "Bosnian"
    }, 
    "rus": {
        "terminologic": "", 
        "alpha2": "ru", 
        "french": "russe", 
        "bibliographic": "rus", 
        "english": "Russian"
    }, 
    "rup": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "aroumain; mac\u00e9do-roumain", 
        "bibliographic": "rup", 
        "english": "Aromanian; Arumanian; Macedo-Romanian"
    }, 
    "pli": {
        "terminologic": "", 
        "alpha2": "pi", 
        "french": "pali", 
        "bibliographic": "pli", 
        "english": "Pali"
    }, 
    "om": {
        "terminologic": "", 
        "alpha2": "om", 
        "french": "galla", 
        "bibliographic": "orm", 
        "english": "Oromo"
    }, 
    "oj": {
        "terminologic": "", 
        "alpha2": "oj", 
        "french": "ojibwa", 
        "bibliographic": "oji", 
        "english": "Ojibwa"
    }, 
    "ace": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "aceh", 
        "bibliographic": "ace", 
        "english": "Achinese"
    }, 
    "ach": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "acoli", 
        "bibliographic": "ach", 
        "english": "Acoli"
    }, 
    "nde": {
        "terminologic": "", 
        "alpha2": "nd", 
        "french": "nd\u00e9b\u00e9l\u00e9 du Nord", 
        "bibliographic": "nde", 
        "english": "Ndebele, North; North Ndebele"
    }, 
    "dzo": {
        "terminologic": "", 
        "alpha2": "dz", 
        "french": "dzongkha", 
        "bibliographic": "dzo", 
        "english": "Dzongkha"
    }, 
    "kru": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "kurukh", 
        "bibliographic": "kru", 
        "english": "Kurukh"
    }, 
    "srr": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "s\u00e9r\u00e8re", 
        "bibliographic": "srr", 
        "english": "Serer"
    }, 
    "ido": {
        "terminologic": "", 
        "alpha2": "io", 
        "french": "ido", 
        "bibliographic": "ido", 
        "english": "Ido"
    }, 
    "srp": {
        "terminologic": "", 
        "alpha2": "sr", 
        "french": "serbe", 
        "bibliographic": "srp", 
        "english": "Serbian"
    }, 
    "kro": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "krou, langues", 
        "bibliographic": "kro", 
        "english": "Kru languages"
    }, 
    "krl": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "car\u00e9lien", 
        "bibliographic": "krl", 
        "english": "Karelian"
    }, 
    "krc": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "karatchai balkar", 
        "bibliographic": "krc", 
        "english": "Karachay-Balkar"
    }, 
    "nds": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "bas allemand; bas saxon; allemand, bas; saxon, bas", 
        "bibliographic": "nds", 
        "english": "Low German; Low Saxon; German, Low; Saxon, Low"
    }, 
    "os": {
        "terminologic": "", 
        "alpha2": "os", 
        "french": "oss\u00e8te", 
        "bibliographic": "oss", 
        "english": "Ossetian; Ossetic"
    }, 
    "or": {
        "terminologic": "", 
        "alpha2": "or", 
        "french": "oriya", 
        "bibliographic": "ori", 
        "english": "Oriya"
    }, 
    "zul": {
        "terminologic": "", 
        "alpha2": "zu", 
        "french": "zoulou", 
        "bibliographic": "zul", 
        "english": "Zulu"
    }, 
    "twi": {
        "terminologic": "", 
        "alpha2": "tw", 
        "french": "twi", 
        "bibliographic": "twi", 
        "english": "Twi"
    }, 
    "sog": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "sogdien", 
        "bibliographic": "sog", 
        "english": "Sogdian"
    }, 
    "nso": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "pedi; sepedi; sotho du Nord", 
        "bibliographic": "nso", 
        "english": "Pedi; Sepedi; Northern Sotho"
    }, 
    "swe": {
        "terminologic": "", 
        "alpha2": "sv", 
        "french": "su\u00e9dois", 
        "bibliographic": "swe", 
        "english": "Swedish"
    }, 
    "som": {
        "terminologic": "", 
        "alpha2": "so", 
        "french": "somali", 
        "bibliographic": "som", 
        "english": "Somali"
    }, 
    "son": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "songhai, langues", 
        "bibliographic": "son", 
        "english": "Songhai languages"
    }, 
    "snd": {
        "terminologic": "", 
        "alpha2": "sd", 
        "french": "sindhi", 
        "bibliographic": "snd", 
        "english": "Sindhi"
    }, 
    "sot": {
        "terminologic": "", 
        "alpha2": "st", 
        "french": "sotho du Sud", 
        "bibliographic": "sot", 
        "english": "Sotho, Southern"
    }, 
    "mkd": {
        "terminologic": "mkd", 
        "alpha2": "mk", 
        "french": "mac\u00e9donien", 
        "bibliographic": "mac", 
        "english": "Macedonian"
    }, 
    "wak": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "wakashanes, langues", 
        "bibliographic": "wak", 
        "english": "Wakashan languages"
    }, 
    "her": {
        "terminologic": "", 
        "alpha2": "hz", 
        "french": "herero", 
        "bibliographic": "her", 
        "english": "Herero"
    }, 
    "lol": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "mongo", 
        "bibliographic": "lol", 
        "english": "Mongo"
    }, 
    "mkh": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "m\u00f4n-khmer, langues", 
        "bibliographic": "mkh", 
        "english": "Mon-Khmer languages"
    }, 
    "heb": {
        "terminologic": "", 
        "alpha2": "he", 
        "french": "h\u00e9breu", 
        "bibliographic": "heb", 
        "english": "Hebrew"
    }, 
    "loz": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "lozi", 
        "bibliographic": "loz", 
        "english": "Lozi"
    }, 
    "gil": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "kiribati", 
        "bibliographic": "gil", 
        "english": "Gilbertese"
    }, 
    "was": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "washo", 
        "bibliographic": "was", 
        "english": "Washo"
    }, 
    "war": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "waray", 
        "bibliographic": "war", 
        "english": "Waray"
    }, 
    "hz": {
        "terminologic": "", 
        "alpha2": "hz", 
        "french": "herero", 
        "bibliographic": "her", 
        "english": "Herero"
    }, 
    "hy": {
        "terminologic": "hye", 
        "alpha2": "hy", 
        "french": "arm\u00e9nien", 
        "bibliographic": "arm", 
        "english": "Armenian"
    }, 
    "sid": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "sidamo", 
        "bibliographic": "sid", 
        "english": "Sidamo"
    }, 
    "hr": {
        "terminologic": "", 
        "alpha2": "hr", 
        "french": "croate", 
        "bibliographic": "hrv", 
        "english": "Croatian"
    }, 
    "ht": {
        "terminologic": "", 
        "alpha2": "ht", 
        "french": "ha\u00eftien; cr\u00e9ole ha\u00eftien", 
        "bibliographic": "hat", 
        "english": "Haitian; Haitian Creole"
    }, 
    "hu": {
        "terminologic": "", 
        "alpha2": "hu", 
        "french": "hongrois", 
        "bibliographic": "hun", 
        "english": "Hungarian"
    }, 
    "hi": {
        "terminologic": "", 
        "alpha2": "hi", 
        "french": "hindi", 
        "bibliographic": "hin", 
        "english": "Hindi"
    }, 
    "ho": {
        "terminologic": "", 
        "alpha2": "ho", 
        "french": "hiri motu", 
        "bibliographic": "hmo", 
        "english": "Hiri Motu"
    }, 
    "bul": {
        "terminologic": "", 
        "alpha2": "bg", 
        "french": "bulgare", 
        "bibliographic": "bul", 
        "english": "Bulgarian"
    }, 
    "wal": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "walamo", 
        "bibliographic": "wal", 
        "english": "Walamo"
    }, 
    "ha": {
        "terminologic": "", 
        "alpha2": "ha", 
        "french": "haoussa", 
        "bibliographic": "hau", 
        "english": "Hausa"
    }, 
    "bug": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "bugi", 
        "bibliographic": "bug", 
        "english": "Buginese"
    }, 
    "he": {
        "terminologic": "", 
        "alpha2": "he", 
        "french": "h\u00e9breu", 
        "bibliographic": "heb", 
        "english": "Hebrew"
    }, 
    "uz": {
        "terminologic": "", 
        "alpha2": "uz", 
        "french": "ouszbek", 
        "bibliographic": "uzb", 
        "english": "Uzbek"
    }, 
    "aze": {
        "terminologic": "", 
        "alpha2": "az", 
        "french": "az\u00e9ri", 
        "bibliographic": "aze", 
        "english": "Azerbaijani"
    }, 
    "ur": {
        "terminologic": "", 
        "alpha2": "ur", 
        "french": "ourdou", 
        "bibliographic": "urd", 
        "english": "Urdu"
    }, 
    "zha": {
        "terminologic": "", 
        "alpha2": "za", 
        "french": "zhuang; chuang", 
        "bibliographic": "zha", 
        "english": "Zhuang; Chuang"
    }, 
    "uk": {
        "terminologic": "", 
        "alpha2": "uk", 
        "french": "ukrainien", 
        "bibliographic": "ukr", 
        "english": "Ukrainian"
    }, 
    "ug": {
        "terminologic": "", 
        "alpha2": "ug", 
        "french": "ou\u00efgour", 
        "bibliographic": "uig", 
        "english": "Uighur; Uyghur"
    }, 
    "zho": {
        "terminologic": "zho", 
        "alpha2": "zh", 
        "french": "chinois", 
        "bibliographic": "chi", 
        "english": "Chinese"
    }, 
    "aa": {
        "terminologic": "", 
        "alpha2": "aa", 
        "french": "afar", 
        "bibliographic": "\ufeffaar", 
        "english": "Afar"
    }, 
    "ab": {
        "terminologic": "", 
        "alpha2": "ab", 
        "french": "abkhaze", 
        "bibliographic": "abk", 
        "english": "Abkhazian"
    }, 
    "ae": {
        "terminologic": "", 
        "alpha2": "ae", 
        "french": "avestique", 
        "bibliographic": "ave", 
        "english": "Avestan"
    }, 
    "uig": {
        "terminologic": "", 
        "alpha2": "ug", 
        "french": "ou\u00efgour", 
        "bibliographic": "uig", 
        "english": "Uighur; Uyghur"
    }, 
    "af": {
        "terminologic": "", 
        "alpha2": "af", 
        "french": "afrikaans", 
        "bibliographic": "afr", 
        "english": "Afrikaans"
    }, 
    "ak": {
        "terminologic": "", 
        "alpha2": "ak", 
        "french": "akan", 
        "bibliographic": "aka", 
        "english": "Akan"
    }, 
    "am": {
        "terminologic": "", 
        "alpha2": "am", 
        "french": "amharique", 
        "bibliographic": "amh", 
        "english": "Amharic"
    }, 
    "an": {
        "terminologic": "", 
        "alpha2": "an", 
        "french": "aragonais", 
        "bibliographic": "arg", 
        "english": "Aragonese"
    }, 
    "khi": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "kho\u00efsan, langues", 
        "bibliographic": "khi", 
        "english": "Khoisan languages"
    }, 
    "as": {
        "terminologic": "", 
        "alpha2": "as", 
        "french": "assamais", 
        "bibliographic": "asm", 
        "english": "Assamese"
    }, 
    "ar": {
        "terminologic": "", 
        "alpha2": "ar", 
        "french": "arabe", 
        "bibliographic": "ara", 
        "english": "Arabic"
    }, 
    "inh": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "ingouche", 
        "bibliographic": "inh", 
        "english": "Ingush"
    }, 
    "khm": {
        "terminologic": "", 
        "alpha2": "km", 
        "french": "khmer central", 
        "bibliographic": "khm", 
        "english": "Central Khmer"
    }, 
    "kho": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "khotanais; sakan", 
        "bibliographic": "kho", 
        "english": "Khotanese; Sakan"
    }, 
    "ind": {
        "terminologic": "", 
        "alpha2": "id", 
        "french": "indon\u00e9sien", 
        "bibliographic": "ind", 
        "english": "Indonesian"
    }, 
    "kha": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "khasi", 
        "bibliographic": "kha", 
        "english": "Khasi"
    }, 
    "az": {
        "terminologic": "", 
        "alpha2": "az", 
        "french": "az\u00e9ri", 
        "bibliographic": "aze", 
        "english": "Azerbaijani"
    }, 
    "ina": {
        "terminologic": "", 
        "alpha2": "ia", 
        "french": "interlingua (langue auxiliaire internationale)", 
        "bibliographic": "ina", 
        "english": "Interlingua (International Auxiliary Language Association)"
    }, 
    "inc": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "indo-aryennes, langues", 
        "bibliographic": "inc", 
        "english": "Indic languages"
    }, 
    "nl": {
        "terminologic": "nld", 
        "alpha2": "nl", 
        "french": "n\u00e9erlandais; flamand", 
        "bibliographic": "dut", 
        "english": "Dutch; Flemish"
    }, 
    "nn": {
        "terminologic": "", 
        "alpha2": "nn", 
        "french": "norv\u00e9gien nynorsk; nynorsk, norv\u00e9gien", 
        "bibliographic": "nno", 
        "english": "Norwegian Nynorsk; Nynorsk, Norwegian"
    }, 
    "no": {
        "terminologic": "", 
        "alpha2": "no", 
        "french": "norv\u00e9gien", 
        "bibliographic": "nor", 
        "english": "Norwegian"
    }, 
    "na": {
        "terminologic": "", 
        "alpha2": "na", 
        "french": "nauruan", 
        "bibliographic": "nau", 
        "english": "Nauru"
    }, 
    "nah": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "nahuatl, langues", 
        "bibliographic": "nah", 
        "english": "Nahuatl languages"
    }, 
    "nai": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "nord-am\u00e9rindiennes, langues", 
        "bibliographic": "nai", 
        "english": "North American Indian languages"
    }, 
    "nd": {
        "terminologic": "", 
        "alpha2": "nd", 
        "french": "nd\u00e9b\u00e9l\u00e9 du Nord", 
        "bibliographic": "nde", 
        "english": "Ndebele, North; North Ndebele"
    }, 
    "ne": {
        "terminologic": "", 
        "alpha2": "ne", 
        "french": "n\u00e9palais", 
        "bibliographic": "nep", 
        "english": "Nepali"
    }, 
    "tir": {
        "terminologic": "", 
        "alpha2": "ti", 
        "french": "tigrigna", 
        "bibliographic": "tir", 
        "english": "Tigrinya"
    }, 
    "ng": {
        "terminologic": "", 
        "alpha2": "ng", 
        "french": "ndonga", 
        "bibliographic": "ndo", 
        "english": "Ndonga"
    }, 
    "ny": {
        "terminologic": "", 
        "alpha2": "ny", 
        "french": "chichewa; chewa; nyanja", 
        "bibliographic": "nya", 
        "english": "Chichewa; Chewa; Nyanja"
    }, 
    "nap": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "napolitain", 
        "bibliographic": "nap", 
        "english": "Neapolitan"
    }, 
    "gre": {
        "terminologic": "ell", 
        "alpha2": "el", 
        "french": "grec moderne (apr\u00e8s 1453)", 
        "bibliographic": "gre", 
        "english": "Greek, Modern (1453-)"
    }, 
    "grb": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "grebo", 
        "bibliographic": "grb", 
        "english": "Grebo"
    }, 
    "grc": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "grec ancien (jusqu'\u00e0 1453)", 
        "bibliographic": "grc", 
        "english": "Greek, Ancient (to 1453)"
    }, 
    "nau": {
        "terminologic": "", 
        "alpha2": "na", 
        "french": "nauruan", 
        "bibliographic": "nau", 
        "english": "Nauru"
    }, 
    "grn": {
        "terminologic": "", 
        "alpha2": "gn", 
        "french": "guarani", 
        "bibliographic": "grn", 
        "english": "Guarani"
    }, 
    "nr": {
        "terminologic": "", 
        "alpha2": "nr", 
        "french": "nd\u00e9b\u00e9l\u00e9 du Sud", 
        "bibliographic": "nbl", 
        "english": "Ndebele, South; South Ndebele"
    }, 
    "tig": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "tigr\u00e9", 
        "bibliographic": "tig", 
        "english": "Tigre"
    }, 
    "yor": {
        "terminologic": "", 
        "alpha2": "yo", 
        "french": "yoruba", 
        "bibliographic": "yor", 
        "english": "Yoruba"
    }, 
    "nv": {
        "terminologic": "", 
        "alpha2": "nv", 
        "french": "navaho", 
        "bibliographic": "nav", 
        "english": "Navajo; Navaho"
    }, 
    "mri": {
        "terminologic": "mri", 
        "alpha2": "mi", 
        "french": "maori", 
        "bibliographic": "mao", 
        "english": "Maori"
    }, 
    "zun": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "zuni", 
        "bibliographic": "zun", 
        "english": "Zuni"
    }, 
    "sqi": {
        "terminologic": "sqi", 
        "alpha2": "sq", 
        "french": "albanais", 
        "bibliographic": "alb", 
        "english": "Albanian"
    }, 
    "gon": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "gond", 
        "bibliographic": "gon", 
        "english": "Gondi"
    }, 
    "\ufeffaar": {
        "terminologic": "", 
        "alpha2": "aa", 
        "french": "afar", 
        "bibliographic": "\ufeffaar", 
        "english": "Afar"
    }, 
    "cpe": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "cr\u00e9oles et pidgins bas\u00e9s sur l'anglais", 
        "bibliographic": "cpe", 
        "english": "Creoles and pidgins, English based"
    }, 
    "cpf": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "cr\u00e9oles et pidgins bas\u00e9s sur le fran\u00e7ais", 
        "bibliographic": "cpf", 
        "english": "Creoles and pidgins, French-based "
    }, 
    "hmo": {
        "terminologic": "", 
        "alpha2": "ho", 
        "french": "hiri motu", 
        "bibliographic": "hmo", 
        "english": "Hiri Motu"
    }, 
    "cpp": {
        "terminologic": "", 
        "alpha2": "", 
        "french": "cr\u00e9oles et pidgins bas\u00e9s sur le portugais", 
        "bibliographic": "cpp", 
        "english": "Creoles and pidgins, Portuguese-based "
    }
}



# Misc utility functions
# By Braddock Gaskill, Feb 2013
from subprocess import Popen, PIPE
import re
import sys


def is32bit():
    """Returns true if this is a 32-bit architecture, or false if 64-bit"""
    return not sys.maxsize > 2 ** 32


def whoosh_open_dir_32_or_64(dirname, indexname=None, readonly=False):
    """Convenience function for opening an index in a directory based on
    open_dir in whoosh.index.
    This functions automatically detects if the machine is 32-bit or 64-bit,
    and turns off mmap if only 32-bit to avoid address space exhaustion
    on large indices.

    :param dirname: the path string of the directory in which to create the
        index.
    :param indexname: the name of the index to create; you only need to specify
        this if you have multiple indexes within the same storage object.
    """

    from whoosh.filedb.filestore import FileStorage
    from whoosh.index import _DEF_INDEX_NAME

    supports_mmap = not is32bit()
    if indexname is None:
        indexname = _DEF_INDEX_NAME

    storage = FileStorage(dirname, readonly=readonly, supports_mmap=supports_mmap)
    return storage.open_index(indexname)


def whoosh2dict(hits):
    """Convert from whoosh results list to
    a list of dictionaries with a key/value pair for
    each schema column"""
    m = []
    for hit in hits:
        d = {}
        for k, v in hit.items():
            d[k] = v
        m.append(d)
    return m


def run_mount():
    """Run the mount command and return the parsed results"""
    p = Popen(['mount'], stdout=PIPE)
    data = p.stdout.readlines()
    regex = '(.*) on (.*) type ([^ ]*) (.*)\n'
    r = []
    for line in data:
        m = re.match(regex, line)
        if m is not None:
            r.append(m.groups())
    return r


def mdns_resolve(mdnsname):
    p = Popen(['avahi-resolve', '-4', '-n', mdnsname], stdout=PIPE)
    data = p.stdout.read()
    if data == '':  # Failed to resolve
        return None
    data = data.rstrip()
    fields = data.split("\t")
    return fields[1]
